@@ -32,52 +32,10 @@ impl core::convert::From<crate::W<CTL1_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Idle state of channel 3 output\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ISO3_A {
-    #[doc = "0: CH3_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    LOW = 0,
-    #[doc = "1: CH3_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    HIGH = 1,
-}
-impl From<ISO3_A> for bool {
-    #[inline(always)]
-    fn from(variant: ISO3_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Idle state of channel 3 output"]
+pub type ISO3_A = ISO0_A;
 #[doc = "Field `ISO3` reader - Idle state of channel 3 output"]
-pub struct ISO3_R(crate::FieldReader<bool, ISO3_A>);
-impl ISO3_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ISO3_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ISO3_A {
-        match self.bits {
-            false => ISO3_A::LOW,
-            true => ISO3_A::HIGH,
-        }
-    }
-    #[doc = "Checks if the value of the field is `LOW`"]
-    #[inline(always)]
-    pub fn is_low(&self) -> bool {
-        **self == ISO3_A::LOW
-    }
-    #[doc = "Checks if the value of the field is `HIGH`"]
-    #[inline(always)]
-    pub fn is_high(&self) -> bool {
-        **self == ISO3_A::HIGH
-    }
-}
-impl core::ops::Deref for ISO3_R {
-    type Target = crate::FieldReader<bool, ISO3_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ISO3_R = ISO0_R;
 #[doc = "Field `ISO3` writer - Idle state of channel 3 output"]
 pub struct ISO3_W<'a> {
     w: &'a mut W,
@@ -88,12 +46,12 @@ impl<'a> ISO3_W<'a> {
     pub fn variant(self, variant: ISO3_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH3_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=0 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO3_A::LOW)
     }
-    #[doc = "CH3_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=1 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO3_A::HIGH)
@@ -115,52 +73,10 @@ impl<'a> ISO3_W<'a> {
         self.w
     }
 }
-#[doc = "Idle state of channel 2 complementary output\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ISO2N_A {
-    #[doc = "0: CH2_ON=0 when POEN=0"]
-    LOW = 0,
-    #[doc = "1: CH2_ON=1 when POEN=0"]
-    HIGH = 1,
-}
-impl From<ISO2N_A> for bool {
-    #[inline(always)]
-    fn from(variant: ISO2N_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Idle state of channel 2 complementary output"]
+pub type ISO2N_A = ISO0N_A;
 #[doc = "Field `ISO2N` reader - Idle state of channel 2 complementary output"]
-pub struct ISO2N_R(crate::FieldReader<bool, ISO2N_A>);
-impl ISO2N_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ISO2N_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ISO2N_A {
-        match self.bits {
-            false => ISO2N_A::LOW,
-            true => ISO2N_A::HIGH,
-        }
-    }
-    #[doc = "Checks if the value of the field is `LOW`"]
-    #[inline(always)]
-    pub fn is_low(&self) -> bool {
-        **self == ISO2N_A::LOW
-    }
-    #[doc = "Checks if the value of the field is `HIGH`"]
-    #[inline(always)]
-    pub fn is_high(&self) -> bool {
-        **self == ISO2N_A::HIGH
-    }
-}
-impl core::ops::Deref for ISO2N_R {
-    type Target = crate::FieldReader<bool, ISO2N_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ISO2N_R = ISO0N_R;
 #[doc = "Field `ISO2N` writer - Idle state of channel 2 complementary output"]
 pub struct ISO2N_W<'a> {
     w: &'a mut W,
@@ -171,12 +87,12 @@ impl<'a> ISO2N_W<'a> {
     pub fn variant(self, variant: ISO2N_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH2_ON=0 when POEN=0"]
+    #[doc = "CHn_ON=0 when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO2N_A::LOW)
     }
-    #[doc = "CH2_ON=1 when POEN=0"]
+    #[doc = "CHn_ON=1 when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO2N_A::HIGH)
@@ -198,52 +114,10 @@ impl<'a> ISO2N_W<'a> {
         self.w
     }
 }
-#[doc = "Idle state of channel 2 output\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ISO2_A {
-    #[doc = "0: CH2_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    LOW = 0,
-    #[doc = "1: CH2_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    HIGH = 1,
-}
-impl From<ISO2_A> for bool {
-    #[inline(always)]
-    fn from(variant: ISO2_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Idle state of channel 2 output"]
+pub type ISO2_A = ISO0_A;
 #[doc = "Field `ISO2` reader - Idle state of channel 2 output"]
-pub struct ISO2_R(crate::FieldReader<bool, ISO2_A>);
-impl ISO2_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ISO2_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ISO2_A {
-        match self.bits {
-            false => ISO2_A::LOW,
-            true => ISO2_A::HIGH,
-        }
-    }
-    #[doc = "Checks if the value of the field is `LOW`"]
-    #[inline(always)]
-    pub fn is_low(&self) -> bool {
-        **self == ISO2_A::LOW
-    }
-    #[doc = "Checks if the value of the field is `HIGH`"]
-    #[inline(always)]
-    pub fn is_high(&self) -> bool {
-        **self == ISO2_A::HIGH
-    }
-}
-impl core::ops::Deref for ISO2_R {
-    type Target = crate::FieldReader<bool, ISO2_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ISO2_R = ISO0_R;
 #[doc = "Field `ISO2` writer - Idle state of channel 2 output"]
 pub struct ISO2_W<'a> {
     w: &'a mut W,
@@ -254,12 +128,12 @@ impl<'a> ISO2_W<'a> {
     pub fn variant(self, variant: ISO2_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH2_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=0 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO2_A::LOW)
     }
-    #[doc = "CH2_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=1 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO2_A::HIGH)
@@ -281,52 +155,10 @@ impl<'a> ISO2_W<'a> {
         self.w
     }
 }
-#[doc = "Idle state of channel 1 complementary output\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ISO1N_A {
-    #[doc = "0: CH1_ON=0 when POEN=0"]
-    LOW = 0,
-    #[doc = "1: CH1_ON=1 when POEN=0"]
-    HIGH = 1,
-}
-impl From<ISO1N_A> for bool {
-    #[inline(always)]
-    fn from(variant: ISO1N_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Idle state of channel 1 complementary output"]
+pub type ISO1N_A = ISO0N_A;
 #[doc = "Field `ISO1N` reader - Idle state of channel 1 complementary output"]
-pub struct ISO1N_R(crate::FieldReader<bool, ISO1N_A>);
-impl ISO1N_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ISO1N_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ISO1N_A {
-        match self.bits {
-            false => ISO1N_A::LOW,
-            true => ISO1N_A::HIGH,
-        }
-    }
-    #[doc = "Checks if the value of the field is `LOW`"]
-    #[inline(always)]
-    pub fn is_low(&self) -> bool {
-        **self == ISO1N_A::LOW
-    }
-    #[doc = "Checks if the value of the field is `HIGH`"]
-    #[inline(always)]
-    pub fn is_high(&self) -> bool {
-        **self == ISO1N_A::HIGH
-    }
-}
-impl core::ops::Deref for ISO1N_R {
-    type Target = crate::FieldReader<bool, ISO1N_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ISO1N_R = ISO0N_R;
 #[doc = "Field `ISO1N` writer - Idle state of channel 1 complementary output"]
 pub struct ISO1N_W<'a> {
     w: &'a mut W,
@@ -337,12 +169,12 @@ impl<'a> ISO1N_W<'a> {
     pub fn variant(self, variant: ISO1N_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH1_ON=0 when POEN=0"]
+    #[doc = "CHn_ON=0 when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO1N_A::LOW)
     }
-    #[doc = "CH1_ON=1 when POEN=0"]
+    #[doc = "CHn_ON=1 when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO1N_A::HIGH)
@@ -364,52 +196,10 @@ impl<'a> ISO1N_W<'a> {
         self.w
     }
 }
-#[doc = "Idle state of channel 1 output\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ISO1_A {
-    #[doc = "0: CH1_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    LOW = 0,
-    #[doc = "1: CH1_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    HIGH = 1,
-}
-impl From<ISO1_A> for bool {
-    #[inline(always)]
-    fn from(variant: ISO1_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Idle state of channel 1 output"]
+pub type ISO1_A = crate::gd32f130::timer0::ctl1::ISO0_A;
 #[doc = "Field `ISO1` reader - Idle state of channel 1 output"]
-pub struct ISO1_R(crate::FieldReader<bool, ISO1_A>);
-impl ISO1_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ISO1_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ISO1_A {
-        match self.bits {
-            false => ISO1_A::LOW,
-            true => ISO1_A::HIGH,
-        }
-    }
-    #[doc = "Checks if the value of the field is `LOW`"]
-    #[inline(always)]
-    pub fn is_low(&self) -> bool {
-        **self == ISO1_A::LOW
-    }
-    #[doc = "Checks if the value of the field is `HIGH`"]
-    #[inline(always)]
-    pub fn is_high(&self) -> bool {
-        **self == ISO1_A::HIGH
-    }
-}
-impl core::ops::Deref for ISO1_R {
-    type Target = crate::FieldReader<bool, ISO1_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ISO1_R = crate::gd32f130::timer0::ctl1::ISO0_R;
 #[doc = "Field `ISO1` writer - Idle state of channel 1 output"]
 pub struct ISO1_W<'a> {
     w: &'a mut W,
@@ -420,12 +210,12 @@ impl<'a> ISO1_W<'a> {
     pub fn variant(self, variant: ISO1_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH1_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=0 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO1_A::LOW)
     }
-    #[doc = "CH1_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=1 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO1_A::HIGH)
@@ -450,9 +240,9 @@ impl<'a> ISO1_W<'a> {
 #[doc = "Idle state of channel 0 complementary output\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ISO0N_A {
-    #[doc = "0: CH0_ON=0 when POEN=0"]
+    #[doc = "0: CHn_ON=0 when POEN=0"]
     LOW = 0,
-    #[doc = "1: CH0_ON=1 when POEN=0"]
+    #[doc = "1: CHn_ON=1 when POEN=0"]
     HIGH = 1,
 }
 impl From<ISO0N_A> for bool {
@@ -503,12 +293,12 @@ impl<'a> ISO0N_W<'a> {
     pub fn variant(self, variant: ISO0N_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH0_ON=0 when POEN=0"]
+    #[doc = "CHn_ON=0 when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO0N_A::LOW)
     }
-    #[doc = "CH0_ON=1 when POEN=0"]
+    #[doc = "CHn_ON=1 when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO0N_A::HIGH)
@@ -533,9 +323,9 @@ impl<'a> ISO0N_W<'a> {
 #[doc = "Idle state of channel 0 output\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ISO0_A {
-    #[doc = "0: CH0_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "0: CHn_O=0 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     LOW = 0,
-    #[doc = "1: CH0_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "1: CHn_O=1 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     HIGH = 1,
 }
 impl From<ISO0_A> for bool {
@@ -586,12 +376,12 @@ impl<'a> ISO0_W<'a> {
     pub fn variant(self, variant: ISO0_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH0_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=0 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO0_A::LOW)
     }
-    #[doc = "CH0_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=1 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO0_A::HIGH)
