@@ -32,52 +32,10 @@ impl core::convert::From<crate::W<CHCTL2_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Channel 3 complementary output polarity\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3NP_A {
-    #[doc = "0: Complementary channel is active high"]
-    NOTINVERTED = 0,
-    #[doc = "1: Complementary channel is active low"]
-    INVERTED = 1,
-}
-impl From<CH3NP_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3NP_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 complementary output polarity"]
+pub type CH3NP_A = crate::gd32f130::timer0::chctl2::CH0P_A;
 #[doc = "Field `CH3NP` reader - Channel 3 complementary output polarity"]
-pub struct CH3NP_R(crate::FieldReader<bool, CH3NP_A>);
-impl CH3NP_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3NP_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3NP_A {
-        match self.bits {
-            false => CH3NP_A::NOTINVERTED,
-            true => CH3NP_A::INVERTED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `NOTINVERTED`"]
-    #[inline(always)]
-    pub fn is_not_inverted(&self) -> bool {
-        **self == CH3NP_A::NOTINVERTED
-    }
-    #[doc = "Checks if the value of the field is `INVERTED`"]
-    #[inline(always)]
-    pub fn is_inverted(&self) -> bool {
-        **self == CH3NP_A::INVERTED
-    }
-}
-impl core::ops::Deref for CH3NP_R {
-    type Target = crate::FieldReader<bool, CH3NP_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3NP_R = crate::gd32f130::timer0::chctl2::CH0P_R;
 #[doc = "Field `CH3NP` writer - Channel 3 complementary output polarity"]
 pub struct CH3NP_W<'a> {
     w: &'a mut W,
@@ -88,12 +46,12 @@ impl<'a> CH3NP_W<'a> {
     pub fn variant(self, variant: CH3NP_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Complementary channel is active high"]
+    #[doc = "Active high"]
     #[inline(always)]
     pub fn not_inverted(self) -> &'a mut W {
         self.variant(CH3NP_A::NOTINVERTED)
     }
-    #[doc = "Complementary channel is active low"]
+    #[doc = "Active low"]
     #[inline(always)]
     pub fn inverted(self) -> &'a mut W {
         self.variant(CH3NP_A::INVERTED)
@@ -115,52 +73,10 @@ impl<'a> CH3NP_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 polarity\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3P_A {
-    #[doc = "0: Channel is active high"]
-    NOTINVERTED = 0,
-    #[doc = "1: Channel is active low"]
-    INVERTED = 1,
-}
-impl From<CH3P_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3P_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 polarity"]
+pub type CH3P_A = crate::gd32f130::timer0::chctl2::CH0P_A;
 #[doc = "Field `CH3P` reader - Channel 3 polarity"]
-pub struct CH3P_R(crate::FieldReader<bool, CH3P_A>);
-impl CH3P_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3P_A {
-        match self.bits {
-            false => CH3P_A::NOTINVERTED,
-            true => CH3P_A::INVERTED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `NOTINVERTED`"]
-    #[inline(always)]
-    pub fn is_not_inverted(&self) -> bool {
-        **self == CH3P_A::NOTINVERTED
-    }
-    #[doc = "Checks if the value of the field is `INVERTED`"]
-    #[inline(always)]
-    pub fn is_inverted(&self) -> bool {
-        **self == CH3P_A::INVERTED
-    }
-}
-impl core::ops::Deref for CH3P_R {
-    type Target = crate::FieldReader<bool, CH3P_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3P_R = crate::gd32f130::timer0::chctl2::CH0P_R;
 #[doc = "Field `CH3P` writer - Channel 3 polarity"]
 pub struct CH3P_W<'a> {
     w: &'a mut W,
@@ -171,12 +87,12 @@ impl<'a> CH3P_W<'a> {
     pub fn variant(self, variant: CH3P_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Channel is active high"]
+    #[doc = "Active high"]
     #[inline(always)]
     pub fn not_inverted(self) -> &'a mut W {
         self.variant(CH3P_A::NOTINVERTED)
     }
-    #[doc = "Channel is active low"]
+    #[doc = "Active low"]
     #[inline(always)]
     pub fn inverted(self) -> &'a mut W {
         self.variant(CH3P_A::INVERTED)
@@ -198,52 +114,10 @@ impl<'a> CH3P_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3EN_A {
-    #[doc = "0: Channel output is disabled"]
-    DISABLED = 0,
-    #[doc = "1: Channel output is enabled"]
-    ENABLED = 1,
-}
-impl From<CH3EN_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3EN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 enable"]
+pub type CH3EN_A = crate::gd32f130::timer0::chctl2::CH0EN_A;
 #[doc = "Field `CH3EN` reader - Channel 3 enable"]
-pub struct CH3EN_R(crate::FieldReader<bool, CH3EN_A>);
-impl CH3EN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3EN_A {
-        match self.bits {
-            false => CH3EN_A::DISABLED,
-            true => CH3EN_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == CH3EN_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == CH3EN_A::ENABLED
-    }
-}
-impl core::ops::Deref for CH3EN_R {
-    type Target = crate::FieldReader<bool, CH3EN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3EN_R = crate::gd32f130::timer0::chctl2::CH0EN_R;
 #[doc = "Field `CH3EN` writer - Channel 3 enable"]
 pub struct CH3EN_W<'a> {
     w: &'a mut W,
@@ -282,9 +156,9 @@ impl<'a> CH3EN_W<'a> {
     }
 }
 #[doc = "Channel 2 complementary output polarity"]
-pub type CH2NP_A = CH3NP_A;
+pub type CH2NP_A = crate::gd32f130::timer0::chctl2::CH0P_A;
 #[doc = "Field `CH2NP` reader - Channel 2 complementary output polarity"]
-pub type CH2NP_R = CH3NP_R;
+pub type CH2NP_R = crate::gd32f130::timer0::chctl2::CH0P_R;
 #[doc = "Field `CH2NP` writer - Channel 2 complementary output polarity"]
 pub struct CH2NP_W<'a> {
     w: &'a mut W,
@@ -295,12 +169,12 @@ impl<'a> CH2NP_W<'a> {
     pub fn variant(self, variant: CH2NP_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Complementary channel is active high"]
+    #[doc = "Active high"]
     #[inline(always)]
     pub fn not_inverted(self) -> &'a mut W {
         self.variant(CH2NP_A::NOTINVERTED)
     }
-    #[doc = "Complementary channel is active low"]
+    #[doc = "Active low"]
     #[inline(always)]
     pub fn inverted(self) -> &'a mut W {
         self.variant(CH2NP_A::INVERTED)
@@ -323,9 +197,9 @@ impl<'a> CH2NP_W<'a> {
     }
 }
 #[doc = "Channel 2 polarity"]
-pub type CH2P_A = CH3P_A;
+pub type CH2P_A = crate::gd32f130::timer0::chctl2::CH0P_A;
 #[doc = "Field `CH2P` reader - Channel 2 polarity"]
-pub type CH2P_R = CH3P_R;
+pub type CH2P_R = crate::gd32f130::timer0::chctl2::CH0P_R;
 #[doc = "Field `CH2P` writer - Channel 2 polarity"]
 pub struct CH2P_W<'a> {
     w: &'a mut W,
@@ -336,12 +210,12 @@ impl<'a> CH2P_W<'a> {
     pub fn variant(self, variant: CH2P_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Channel is active high"]
+    #[doc = "Active high"]
     #[inline(always)]
     pub fn not_inverted(self) -> &'a mut W {
         self.variant(CH2P_A::NOTINVERTED)
     }
-    #[doc = "Channel is active low"]
+    #[doc = "Active low"]
     #[inline(always)]
     pub fn inverted(self) -> &'a mut W {
         self.variant(CH2P_A::INVERTED)
@@ -364,9 +238,9 @@ impl<'a> CH2P_W<'a> {
     }
 }
 #[doc = "Channel 2 enable"]
-pub type CH2EN_A = CH3EN_A;
+pub type CH2EN_A = crate::gd32f130::timer0::chctl2::CH0EN_A;
 #[doc = "Field `CH2EN` reader - Channel 2 enable"]
-pub type CH2EN_R = CH3EN_R;
+pub type CH2EN_R = crate::gd32f130::timer0::chctl2::CH0EN_R;
 #[doc = "Field `CH2EN` writer - Channel 2 enable"]
 pub struct CH2EN_W<'a> {
     w: &'a mut W,
@@ -405,9 +279,9 @@ impl<'a> CH2EN_W<'a> {
     }
 }
 #[doc = "Channel 1 complementary output polarity"]
-pub type CH1NP_A = CH3NP_A;
+pub type CH1NP_A = crate::gd32f130::timer0::chctl2::CH0P_A;
 #[doc = "Field `CH1NP` reader - Channel 1 complementary output polarity"]
-pub type CH1NP_R = CH3NP_R;
+pub type CH1NP_R = crate::gd32f130::timer0::chctl2::CH0P_R;
 #[doc = "Field `CH1NP` writer - Channel 1 complementary output polarity"]
 pub struct CH1NP_W<'a> {
     w: &'a mut W,
@@ -418,12 +292,12 @@ impl<'a> CH1NP_W<'a> {
     pub fn variant(self, variant: CH1NP_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Complementary channel is active high"]
+    #[doc = "Active high"]
     #[inline(always)]
     pub fn not_inverted(self) -> &'a mut W {
         self.variant(CH1NP_A::NOTINVERTED)
     }
-    #[doc = "Complementary channel is active low"]
+    #[doc = "Active low"]
     #[inline(always)]
     pub fn inverted(self) -> &'a mut W {
         self.variant(CH1NP_A::INVERTED)
@@ -446,9 +320,9 @@ impl<'a> CH1NP_W<'a> {
     }
 }
 #[doc = "Channel 1 polarity"]
-pub type CH1P_A = CH3P_A;
+pub type CH1P_A = crate::gd32f130::timer0::chctl2::CH0P_A;
 #[doc = "Field `CH1P` reader - Channel 1 polarity"]
-pub type CH1P_R = CH3P_R;
+pub type CH1P_R = crate::gd32f130::timer0::chctl2::CH0P_R;
 #[doc = "Field `CH1P` writer - Channel 1 polarity"]
 pub struct CH1P_W<'a> {
     w: &'a mut W,
@@ -459,12 +333,12 @@ impl<'a> CH1P_W<'a> {
     pub fn variant(self, variant: CH1P_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Channel is active high"]
+    #[doc = "Active high"]
     #[inline(always)]
     pub fn not_inverted(self) -> &'a mut W {
         self.variant(CH1P_A::NOTINVERTED)
     }
-    #[doc = "Channel is active low"]
+    #[doc = "Active low"]
     #[inline(always)]
     pub fn inverted(self) -> &'a mut W {
         self.variant(CH1P_A::INVERTED)
@@ -487,9 +361,9 @@ impl<'a> CH1P_W<'a> {
     }
 }
 #[doc = "Channel 1 enable"]
-pub type CH1EN_A = CH3EN_A;
+pub type CH1EN_A = crate::gd32f130::timer0::chctl2::CH0EN_A;
 #[doc = "Field `CH1EN` reader - Channel 1 enable"]
-pub type CH1EN_R = CH3EN_R;
+pub type CH1EN_R = crate::gd32f130::timer0::chctl2::CH0EN_R;
 #[doc = "Field `CH1EN` writer - Channel 1 enable"]
 pub struct CH1EN_W<'a> {
     w: &'a mut W,
@@ -528,9 +402,9 @@ impl<'a> CH1EN_W<'a> {
     }
 }
 #[doc = "Channel 0 complementary output polarity"]
-pub type CH0NP_A = CH3NP_A;
+pub type CH0NP_A = crate::gd32f130::timer0::chctl2::CH0P_A;
 #[doc = "Field `CH0NP` reader - Channel 0 complementary output polarity"]
-pub type CH0NP_R = CH3NP_R;
+pub type CH0NP_R = crate::gd32f130::timer0::chctl2::CH0P_R;
 #[doc = "Field `CH0NP` writer - Channel 0 complementary output polarity"]
 pub struct CH0NP_W<'a> {
     w: &'a mut W,
@@ -541,12 +415,12 @@ impl<'a> CH0NP_W<'a> {
     pub fn variant(self, variant: CH0NP_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Complementary channel is active high"]
+    #[doc = "Active high"]
     #[inline(always)]
     pub fn not_inverted(self) -> &'a mut W {
         self.variant(CH0NP_A::NOTINVERTED)
     }
-    #[doc = "Complementary channel is active low"]
+    #[doc = "Active low"]
     #[inline(always)]
     pub fn inverted(self) -> &'a mut W {
         self.variant(CH0NP_A::INVERTED)
@@ -569,9 +443,9 @@ impl<'a> CH0NP_W<'a> {
     }
 }
 #[doc = "Channel 0 polarity"]
-pub type CH0P_A = CH3P_A;
+pub type CH0P_A = crate::gd32f130::timer0::chctl2::CH0P_A;
 #[doc = "Field `CH0P` reader - Channel 0 polarity"]
-pub type CH0P_R = CH3P_R;
+pub type CH0P_R = crate::gd32f130::timer0::chctl2::CH0P_R;
 #[doc = "Field `CH0P` writer - Channel 0 polarity"]
 pub struct CH0P_W<'a> {
     w: &'a mut W,
@@ -582,12 +456,12 @@ impl<'a> CH0P_W<'a> {
     pub fn variant(self, variant: CH0P_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "Channel is active high"]
+    #[doc = "Active high"]
     #[inline(always)]
     pub fn not_inverted(self) -> &'a mut W {
         self.variant(CH0P_A::NOTINVERTED)
     }
-    #[doc = "Channel is active low"]
+    #[doc = "Active low"]
     #[inline(always)]
     pub fn inverted(self) -> &'a mut W {
         self.variant(CH0P_A::INVERTED)
@@ -610,9 +484,9 @@ impl<'a> CH0P_W<'a> {
     }
 }
 #[doc = "Channel 0 enable"]
-pub type CH0EN_A = CH3EN_A;
+pub type CH0EN_A = crate::gd32f130::timer0::chctl2::CH0EN_A;
 #[doc = "Field `CH0EN` reader - Channel 0 enable"]
-pub type CH0EN_R = CH3EN_R;
+pub type CH0EN_R = crate::gd32f130::timer0::chctl2::CH0EN_R;
 #[doc = "Field `CH0EN` writer - Channel 0 enable"]
 pub struct CH0EN_W<'a> {
     w: &'a mut W,
