@@ -32,62 +32,10 @@ impl core::convert::From<crate::W<CTL0_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Clock division\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CKDIV_A {
-    #[doc = "0: t_DTS = t_CK_INT"]
-    DIV1 = 0,
-    #[doc = "1: t_DTS = 2 × t_CK_INT"]
-    DIV2 = 1,
-    #[doc = "2: t_DTS = 4 × t_CK_INT"]
-    DIV4 = 2,
-}
-impl From<CKDIV_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CKDIV_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Clock division"]
+pub type CKDIV_A = crate::gd32f130::timer0::ctl0::CKDIV_A;
 #[doc = "Field `CKDIV` reader - Clock division"]
-pub struct CKDIV_R(crate::FieldReader<u8, CKDIV_A>);
-impl CKDIV_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CKDIV_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> Option<CKDIV_A> {
-        match self.bits {
-            0 => Some(CKDIV_A::DIV1),
-            1 => Some(CKDIV_A::DIV2),
-            2 => Some(CKDIV_A::DIV4),
-            _ => None,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DIV1`"]
-    #[inline(always)]
-    pub fn is_div1(&self) -> bool {
-        **self == CKDIV_A::DIV1
-    }
-    #[doc = "Checks if the value of the field is `DIV2`"]
-    #[inline(always)]
-    pub fn is_div2(&self) -> bool {
-        **self == CKDIV_A::DIV2
-    }
-    #[doc = "Checks if the value of the field is `DIV4`"]
-    #[inline(always)]
-    pub fn is_div4(&self) -> bool {
-        **self == CKDIV_A::DIV4
-    }
-}
-impl core::ops::Deref for CKDIV_R {
-    type Target = crate::FieldReader<u8, CKDIV_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CKDIV_R = crate::gd32f130::timer0::ctl0::CKDIV_R;
 #[doc = "Field `CKDIV` writer - Clock division"]
 pub struct CKDIV_W<'a> {
     w: &'a mut W,
@@ -120,52 +68,10 @@ impl<'a> CKDIV_W<'a> {
         self.w
     }
 }
-#[doc = "Auto-reload shadow enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ARSE_A {
-    #[doc = "0: The shadow register for CAR is disabled"]
-    DISABLED = 0,
-    #[doc = "1: The shadow register for CAR is enabled"]
-    ENABLED = 1,
-}
-impl From<ARSE_A> for bool {
-    #[inline(always)]
-    fn from(variant: ARSE_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Auto-reload shadow enable"]
+pub type ARSE_A = crate::gd32f130::timer0::ctl0::ARSE_A;
 #[doc = "Field `ARSE` reader - Auto-reload shadow enable"]
-pub struct ARSE_R(crate::FieldReader<bool, ARSE_A>);
-impl ARSE_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ARSE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ARSE_A {
-        match self.bits {
-            false => ARSE_A::DISABLED,
-            true => ARSE_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == ARSE_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == ARSE_A::ENABLED
-    }
-}
-impl core::ops::Deref for ARSE_R {
-    type Target = crate::FieldReader<bool, ARSE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ARSE_R = crate::gd32f130::timer0::ctl0::ARSE_R;
 #[doc = "Field `ARSE` writer - Auto-reload shadow enable"]
 pub struct ARSE_W<'a> {
     w: &'a mut W,
@@ -203,70 +109,10 @@ impl<'a> ARSE_W<'a> {
         self.w
     }
 }
-#[doc = "Counter aligns mode selection\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CAM_A {
-    #[doc = "0: The counter counts up or down depending on the direction bit"]
-    EDGEALIGNED = 0,
-    #[doc = "1: The counter counts up and down alternatively. Output compare interrupt flags are set only when the counter is counting down."]
-    CENTERALIGNEDCOUNTINGDOWN = 1,
-    #[doc = "2: The counter counts up and down alternatively. Output compare interrupt flags are set only when the counter is counting up."]
-    CENTERALIGNEDCOUNTINGUP = 2,
-    #[doc = "3: The counter counts up and down alternatively. Output compare interrupt flags are set both when the counter is counting up or down."]
-    CENTERALIGNEDCOUNTINGUPDOWN = 3,
-}
-impl From<CAM_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CAM_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Counter aligns mode selection"]
+pub type CAM_A = crate::gd32f130::timer0::ctl0::CAM_A;
 #[doc = "Field `CAM` reader - Counter aligns mode selection"]
-pub struct CAM_R(crate::FieldReader<u8, CAM_A>);
-impl CAM_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CAM_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CAM_A {
-        match self.bits {
-            0 => CAM_A::EDGEALIGNED,
-            1 => CAM_A::CENTERALIGNEDCOUNTINGDOWN,
-            2 => CAM_A::CENTERALIGNEDCOUNTINGUP,
-            3 => CAM_A::CENTERALIGNEDCOUNTINGUPDOWN,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `EDGEALIGNED`"]
-    #[inline(always)]
-    pub fn is_edge_aligned(&self) -> bool {
-        **self == CAM_A::EDGEALIGNED
-    }
-    #[doc = "Checks if the value of the field is `CENTERALIGNEDCOUNTINGDOWN`"]
-    #[inline(always)]
-    pub fn is_center_aligned_counting_down(&self) -> bool {
-        **self == CAM_A::CENTERALIGNEDCOUNTINGDOWN
-    }
-    #[doc = "Checks if the value of the field is `CENTERALIGNEDCOUNTINGUP`"]
-    #[inline(always)]
-    pub fn is_center_aligned_counting_up(&self) -> bool {
-        **self == CAM_A::CENTERALIGNEDCOUNTINGUP
-    }
-    #[doc = "Checks if the value of the field is `CENTERALIGNEDCOUNTINGUPDOWN`"]
-    #[inline(always)]
-    pub fn is_center_aligned_counting_up_down(&self) -> bool {
-        **self == CAM_A::CENTERALIGNEDCOUNTINGUPDOWN
-    }
-}
-impl core::ops::Deref for CAM_R {
-    type Target = crate::FieldReader<u8, CAM_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CAM_R = crate::gd32f130::timer0::ctl0::CAM_R;
 #[doc = "Field `CAM` writer - Counter aligns mode selection"]
 pub struct CAM_W<'a> {
     w: &'a mut W,
@@ -304,52 +150,10 @@ impl<'a> CAM_W<'a> {
         self.w
     }
 }
-#[doc = "Direction\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum DIR_A {
-    #[doc = "0: Counter used as upcounter"]
-    UP = 0,
-    #[doc = "1: Counter used as downcounter"]
-    DOWN = 1,
-}
-impl From<DIR_A> for bool {
-    #[inline(always)]
-    fn from(variant: DIR_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Direction"]
+pub type DIR_A = crate::gd32f130::timer0::ctl0::DIR_A;
 #[doc = "Field `DIR` reader - Direction"]
-pub struct DIR_R(crate::FieldReader<bool, DIR_A>);
-impl DIR_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        DIR_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> DIR_A {
-        match self.bits {
-            false => DIR_A::UP,
-            true => DIR_A::DOWN,
-        }
-    }
-    #[doc = "Checks if the value of the field is `UP`"]
-    #[inline(always)]
-    pub fn is_up(&self) -> bool {
-        **self == DIR_A::UP
-    }
-    #[doc = "Checks if the value of the field is `DOWN`"]
-    #[inline(always)]
-    pub fn is_down(&self) -> bool {
-        **self == DIR_A::DOWN
-    }
-}
-impl core::ops::Deref for DIR_R {
-    type Target = crate::FieldReader<bool, DIR_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type DIR_R = crate::gd32f130::timer0::ctl0::DIR_R;
 #[doc = "Field `DIR` writer - Direction"]
 pub struct DIR_W<'a> {
     w: &'a mut W,
@@ -470,52 +274,10 @@ impl<'a> SPM_W<'a> {
         self.w
     }
 }
-#[doc = "Update request source\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum UPS_A {
-    #[doc = "0: Any of counter overflow/underflow, setting UPG, or update through slave mode, generates an update interrupt or DMA request"]
-    ANYEVENT = 0,
-    #[doc = "1: Only counter overflow/underflow generates an update interrupt or DMA request"]
-    COUNTERONLY = 1,
-}
-impl From<UPS_A> for bool {
-    #[inline(always)]
-    fn from(variant: UPS_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Update request source"]
+pub type UPS_A = crate::gd32f130::timer0::ctl0::UPS_A;
 #[doc = "Field `UPS` reader - Update request source"]
-pub struct UPS_R(crate::FieldReader<bool, UPS_A>);
-impl UPS_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        UPS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> UPS_A {
-        match self.bits {
-            false => UPS_A::ANYEVENT,
-            true => UPS_A::COUNTERONLY,
-        }
-    }
-    #[doc = "Checks if the value of the field is `ANYEVENT`"]
-    #[inline(always)]
-    pub fn is_any_event(&self) -> bool {
-        **self == UPS_A::ANYEVENT
-    }
-    #[doc = "Checks if the value of the field is `COUNTERONLY`"]
-    #[inline(always)]
-    pub fn is_counter_only(&self) -> bool {
-        **self == UPS_A::COUNTERONLY
-    }
-}
-impl core::ops::Deref for UPS_R {
-    type Target = crate::FieldReader<bool, UPS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type UPS_R = crate::gd32f130::timer0::ctl0::UPS_R;
 #[doc = "Field `UPS` writer - Update request source"]
 pub struct UPS_W<'a> {
     w: &'a mut W,
@@ -553,52 +315,10 @@ impl<'a> UPS_W<'a> {
         self.w
     }
 }
-#[doc = "Update disable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum UPDIS_A {
-    #[doc = "0: Update event enabled"]
-    ENABLED = 0,
-    #[doc = "1: Update event disabled"]
-    DISABLED = 1,
-}
-impl From<UPDIS_A> for bool {
-    #[inline(always)]
-    fn from(variant: UPDIS_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Update disable"]
+pub type UPDIS_A = crate::gd32f130::timer0::ctl0::UPDIS_A;
 #[doc = "Field `UPDIS` reader - Update disable"]
-pub struct UPDIS_R(crate::FieldReader<bool, UPDIS_A>);
-impl UPDIS_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        UPDIS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> UPDIS_A {
-        match self.bits {
-            false => UPDIS_A::ENABLED,
-            true => UPDIS_A::DISABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == UPDIS_A::ENABLED
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == UPDIS_A::DISABLED
-    }
-}
-impl core::ops::Deref for UPDIS_R {
-    type Target = crate::FieldReader<bool, UPDIS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type UPDIS_R = crate::gd32f130::timer0::ctl0::UPDIS_R;
 #[doc = "Field `UPDIS` writer - Update disable"]
 pub struct UPDIS_W<'a> {
     w: &'a mut W,
@@ -636,52 +356,10 @@ impl<'a> UPDIS_W<'a> {
         self.w
     }
 }
-#[doc = "Counter enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CEN_A {
-    #[doc = "0: Counter disabled"]
-    DISABLED = 0,
-    #[doc = "1: Counter enabled"]
-    ENABLED = 1,
-}
-impl From<CEN_A> for bool {
-    #[inline(always)]
-    fn from(variant: CEN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Counter enable"]
+pub type CEN_A = crate::gd32f130::timer0::ctl0::CEN_A;
 #[doc = "Field `CEN` reader - Counter enable"]
-pub struct CEN_R(crate::FieldReader<bool, CEN_A>);
-impl CEN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CEN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CEN_A {
-        match self.bits {
-            false => CEN_A::DISABLED,
-            true => CEN_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == CEN_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == CEN_A::ENABLED
-    }
-}
-impl core::ops::Deref for CEN_R {
-    type Target = crate::FieldReader<bool, CEN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CEN_R = crate::gd32f130::timer0::ctl0::CEN_R;
 #[doc = "Field `CEN` writer - Counter enable"]
 pub struct CEN_W<'a> {
     w: &'a mut W,
