@@ -32,166 +32,10 @@ impl core::convert::From<crate::W<CHCTL0_INPUT_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Channel 1 input capture filter control\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CH1CAPFLT_A {
-    #[doc = "0: Filter disabled. fSAMP=fDTS, N=1"]
-    NOFILTER = 0,
-    #[doc = "1: fSAMP=fTIMER_CK, N=2"]
-    TIMERCK_N2 = 1,
-    #[doc = "2: fSAMP=fTIMER_CK, N=4"]
-    TIMERCK_N4 = 2,
-    #[doc = "3: fSAMP=fTIMER_CK, N=8"]
-    TIMERCK_N8 = 3,
-    #[doc = "4: fSAMP=fDTS/2, N=6"]
-    FDTS_DIV2_N6 = 4,
-    #[doc = "5: fSAMP=fDTS/2, N=8"]
-    FDTS_DIV2_N8 = 5,
-    #[doc = "6: fSAMP=fDTS/4, N=6"]
-    FDTS_DIV4_N6 = 6,
-    #[doc = "7: fSAMP=fDTS/4, N=8"]
-    FDTS_DIV4_N8 = 7,
-    #[doc = "8: fSAMP=fDTS/8, N=6"]
-    FDTS_DIV8_N6 = 8,
-    #[doc = "9: fSAMP=fDTS/8, N=8"]
-    FDTS_DIV8_N8 = 9,
-    #[doc = "10: fSAMP=fDTS/16, N=5"]
-    FDTS_DIV16_N5 = 10,
-    #[doc = "11: fSAMP=fDTS/16, N=6"]
-    FDTS_DIV16_N6 = 11,
-    #[doc = "12: fSAMP=fDTS/16, N=8"]
-    FDTS_DIV16_N8 = 12,
-    #[doc = "13: fSAMP=fDTS/32, N=5"]
-    FDTS_DIV32_N5 = 13,
-    #[doc = "14: fSAMP=fDTS/32, N=6"]
-    FDTS_DIV32_N6 = 14,
-    #[doc = "15: fSAMP=fDTS/32, N=8"]
-    FDTS_DIV32_N8 = 15,
-}
-impl From<CH1CAPFLT_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CH1CAPFLT_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Channel 1 input capture filter control"]
+pub type CH1CAPFLT_A = crate::gd32f130::timer0::chctl0_input::CH0CAPFLT_A;
 #[doc = "Field `CH1CAPFLT` reader - Channel 1 input capture filter control"]
-pub struct CH1CAPFLT_R(crate::FieldReader<u8, CH1CAPFLT_A>);
-impl CH1CAPFLT_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CH1CAPFLT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH1CAPFLT_A {
-        match self.bits {
-            0 => CH1CAPFLT_A::NOFILTER,
-            1 => CH1CAPFLT_A::TIMERCK_N2,
-            2 => CH1CAPFLT_A::TIMERCK_N4,
-            3 => CH1CAPFLT_A::TIMERCK_N8,
-            4 => CH1CAPFLT_A::FDTS_DIV2_N6,
-            5 => CH1CAPFLT_A::FDTS_DIV2_N8,
-            6 => CH1CAPFLT_A::FDTS_DIV4_N6,
-            7 => CH1CAPFLT_A::FDTS_DIV4_N8,
-            8 => CH1CAPFLT_A::FDTS_DIV8_N6,
-            9 => CH1CAPFLT_A::FDTS_DIV8_N8,
-            10 => CH1CAPFLT_A::FDTS_DIV16_N5,
-            11 => CH1CAPFLT_A::FDTS_DIV16_N6,
-            12 => CH1CAPFLT_A::FDTS_DIV16_N8,
-            13 => CH1CAPFLT_A::FDTS_DIV32_N5,
-            14 => CH1CAPFLT_A::FDTS_DIV32_N6,
-            15 => CH1CAPFLT_A::FDTS_DIV32_N8,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `NOFILTER`"]
-    #[inline(always)]
-    pub fn is_no_filter(&self) -> bool {
-        **self == CH1CAPFLT_A::NOFILTER
-    }
-    #[doc = "Checks if the value of the field is `TIMERCK_N2`"]
-    #[inline(always)]
-    pub fn is_timer_ck_n2(&self) -> bool {
-        **self == CH1CAPFLT_A::TIMERCK_N2
-    }
-    #[doc = "Checks if the value of the field is `TIMERCK_N4`"]
-    #[inline(always)]
-    pub fn is_timer_ck_n4(&self) -> bool {
-        **self == CH1CAPFLT_A::TIMERCK_N4
-    }
-    #[doc = "Checks if the value of the field is `TIMERCK_N8`"]
-    #[inline(always)]
-    pub fn is_timer_ck_n8(&self) -> bool {
-        **self == CH1CAPFLT_A::TIMERCK_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV2_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div2_n6(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV2_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV2_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div2_n8(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV2_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV4_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div4_n6(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV4_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV4_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div4_n8(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV4_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV8_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div8_n6(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV8_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV8_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div8_n8(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV8_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV16_N5`"]
-    #[inline(always)]
-    pub fn is_fdts_div16_n5(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV16_N5
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV16_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div16_n6(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV16_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV16_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div16_n8(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV16_N8
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV32_N5`"]
-    #[inline(always)]
-    pub fn is_fdts_div32_n5(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV32_N5
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV32_N6`"]
-    #[inline(always)]
-    pub fn is_fdts_div32_n6(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV32_N6
-    }
-    #[doc = "Checks if the value of the field is `FDTS_DIV32_N8`"]
-    #[inline(always)]
-    pub fn is_fdts_div32_n8(&self) -> bool {
-        **self == CH1CAPFLT_A::FDTS_DIV32_N8
-    }
-}
-impl core::ops::Deref for CH1CAPFLT_R {
-    type Target = crate::FieldReader<u8, CH1CAPFLT_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH1CAPFLT_R = crate::gd32f130::timer0::chctl0_input::CH0CAPFLT_R;
 #[doc = "Field `CH1CAPFLT` writer - Channel 1 input capture filter control"]
 pub struct CH1CAPFLT_W<'a> {
     w: &'a mut W,
@@ -289,70 +133,10 @@ impl<'a> CH1CAPFLT_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 1 input capture prescaler\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CH1CAPPSC_A {
-    #[doc = "0: Prescaler disabled, capture on every edge"]
-    DIV1 = 0,
-    #[doc = "1: Capture every 2 edges"]
-    DIV2 = 1,
-    #[doc = "2: Capture every 4 edges"]
-    DIV4 = 2,
-    #[doc = "3: Capture every 8 edges"]
-    DIV8 = 3,
-}
-impl From<CH1CAPPSC_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CH1CAPPSC_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Channel 1 input capture prescaler"]
+pub type CH1CAPPSC_A = crate::gd32f130::timer0::chctl0_input::CH0CAPPSC_A;
 #[doc = "Field `CH1CAPPSC` reader - Channel 1 input capture prescaler"]
-pub struct CH1CAPPSC_R(crate::FieldReader<u8, CH1CAPPSC_A>);
-impl CH1CAPPSC_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CH1CAPPSC_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH1CAPPSC_A {
-        match self.bits {
-            0 => CH1CAPPSC_A::DIV1,
-            1 => CH1CAPPSC_A::DIV2,
-            2 => CH1CAPPSC_A::DIV4,
-            3 => CH1CAPPSC_A::DIV8,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `DIV1`"]
-    #[inline(always)]
-    pub fn is_div1(&self) -> bool {
-        **self == CH1CAPPSC_A::DIV1
-    }
-    #[doc = "Checks if the value of the field is `DIV2`"]
-    #[inline(always)]
-    pub fn is_div2(&self) -> bool {
-        **self == CH1CAPPSC_A::DIV2
-    }
-    #[doc = "Checks if the value of the field is `DIV4`"]
-    #[inline(always)]
-    pub fn is_div4(&self) -> bool {
-        **self == CH1CAPPSC_A::DIV4
-    }
-    #[doc = "Checks if the value of the field is `DIV8`"]
-    #[inline(always)]
-    pub fn is_div8(&self) -> bool {
-        **self == CH1CAPPSC_A::DIV8
-    }
-}
-impl core::ops::Deref for CH1CAPPSC_R {
-    type Target = crate::FieldReader<u8, CH1CAPPSC_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH1CAPPSC_R = crate::gd32f130::timer0::chctl0_input::CH0CAPPSC_R;
 #[doc = "Field `CH1CAPPSC` writer - Channel 1 input capture prescaler"]
 pub struct CH1CAPPSC_W<'a> {
     w: &'a mut W,
@@ -390,70 +174,10 @@ impl<'a> CH1CAPPSC_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 1 mode selection\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CH1MS_A {
-    #[doc = "0: Channel is configured as output"]
-    OUTPUT = 0,
-    #[doc = "1: Channel is configured as input, ISx is connected to CI0FEx"]
-    CI0 = 1,
-    #[doc = "2: Channel is configured as input, ISx is connected to CI1FEx"]
-    CI1 = 2,
-    #[doc = "3: Channel is configured as input, ISx is connected to ITS"]
-    ITS = 3,
-}
-impl From<CH1MS_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CH1MS_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Channel 1 mode selection"]
+pub type CH1MS_A = crate::gd32f130::timer0::chctl0_input::CH0MS_A;
 #[doc = "Field `CH1MS` reader - Channel 1 mode selection"]
-pub struct CH1MS_R(crate::FieldReader<u8, CH1MS_A>);
-impl CH1MS_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CH1MS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH1MS_A {
-        match self.bits {
-            0 => CH1MS_A::OUTPUT,
-            1 => CH1MS_A::CI0,
-            2 => CH1MS_A::CI1,
-            3 => CH1MS_A::ITS,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `OUTPUT`"]
-    #[inline(always)]
-    pub fn is_output(&self) -> bool {
-        **self == CH1MS_A::OUTPUT
-    }
-    #[doc = "Checks if the value of the field is `CI0`"]
-    #[inline(always)]
-    pub fn is_ci0(&self) -> bool {
-        **self == CH1MS_A::CI0
-    }
-    #[doc = "Checks if the value of the field is `CI1`"]
-    #[inline(always)]
-    pub fn is_ci1(&self) -> bool {
-        **self == CH1MS_A::CI1
-    }
-    #[doc = "Checks if the value of the field is `ITS`"]
-    #[inline(always)]
-    pub fn is_its(&self) -> bool {
-        **self == CH1MS_A::ITS
-    }
-}
-impl core::ops::Deref for CH1MS_R {
-    type Target = crate::FieldReader<u8, CH1MS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH1MS_R = crate::gd32f130::timer0::chctl0_input::CH0MS_R;
 #[doc = "Field `CH1MS` writer - Channel 1 mode selection"]
 pub struct CH1MS_W<'a> {
     w: &'a mut W,
@@ -492,9 +216,9 @@ impl<'a> CH1MS_W<'a> {
     }
 }
 #[doc = "Channel 0 input capture filter control"]
-pub type CH0CAPFLT_A = CH1CAPFLT_A;
+pub type CH0CAPFLT_A = crate::gd32f130::timer0::chctl0_input::CH0CAPFLT_A;
 #[doc = "Field `CH0CAPFLT` reader - Channel 0 input capture filter control"]
-pub type CH0CAPFLT_R = CH1CAPFLT_R;
+pub type CH0CAPFLT_R = crate::gd32f130::timer0::chctl0_input::CH0CAPFLT_R;
 #[doc = "Field `CH0CAPFLT` writer - Channel 0 input capture filter control"]
 pub struct CH0CAPFLT_W<'a> {
     w: &'a mut W,
@@ -593,9 +317,9 @@ impl<'a> CH0CAPFLT_W<'a> {
     }
 }
 #[doc = "Channel 0 input capture prescaler"]
-pub type CH0CAPPSC_A = CH1CAPPSC_A;
+pub type CH0CAPPSC_A = crate::gd32f130::timer0::chctl0_input::CH0CAPPSC_A;
 #[doc = "Field `CH0CAPPSC` reader - Channel 0 input capture prescaler"]
-pub type CH0CAPPSC_R = CH1CAPPSC_R;
+pub type CH0CAPPSC_R = crate::gd32f130::timer0::chctl0_input::CH0CAPPSC_R;
 #[doc = "Field `CH0CAPPSC` writer - Channel 0 input capture prescaler"]
 pub struct CH0CAPPSC_W<'a> {
     w: &'a mut W,
@@ -634,9 +358,9 @@ impl<'a> CH0CAPPSC_W<'a> {
     }
 }
 #[doc = "Channel 0 mode selection"]
-pub type CH0MS_A = CH1MS_A;
+pub type CH0MS_A = crate::gd32f130::timer0::chctl0_input::CH0MS_A;
 #[doc = "Field `CH0MS` reader - Channel 0 mode selection"]
-pub type CH0MS_R = CH1MS_R;
+pub type CH0MS_R = crate::gd32f130::timer0::chctl0_input::CH0MS_R;
 #[doc = "Field `CH0MS` writer - Channel 0 mode selection"]
 pub struct CH0MS_W<'a> {
     w: &'a mut W,
