@@ -32,52 +32,10 @@ impl core::convert::From<crate::W<INTF_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Channel 3 Capture overflow flag\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3OF_A {
-    #[doc = "0: No over capture occurred"]
-    CLEAR = 0,
-    #[doc = "1: A capture event occured while CH0IF was already set"]
-    OVERCAPTURE = 1,
-}
-impl From<CH3OF_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3OF_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 Capture overflow flag"]
+pub type CH3OF_A = crate::gd32f150::timer0::intf::CH0OF_A;
 #[doc = "Field `CH3OF` reader - Channel 3 Capture overflow flag"]
-pub struct CH3OF_R(crate::FieldReader<bool, CH3OF_A>);
-impl CH3OF_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3OF_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3OF_A {
-        match self.bits {
-            false => CH3OF_A::CLEAR,
-            true => CH3OF_A::OVERCAPTURE,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CLEAR`"]
-    #[inline(always)]
-    pub fn is_clear(&self) -> bool {
-        **self == CH3OF_A::CLEAR
-    }
-    #[doc = "Checks if the value of the field is `OVERCAPTURE`"]
-    #[inline(always)]
-    pub fn is_over_capture(&self) -> bool {
-        **self == CH3OF_A::OVERCAPTURE
-    }
-}
-impl core::ops::Deref for CH3OF_R {
-    type Target = crate::FieldReader<bool, CH3OF_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3OF_R = crate::gd32f150::timer0::intf::CH0OF_R;
 #[doc = "Field `CH3OF` writer - Channel 3 Capture overflow flag"]
 pub struct CH3OF_W<'a> {
     w: &'a mut W,
@@ -93,7 +51,7 @@ impl<'a> CH3OF_W<'a> {
     pub fn clear(self) -> &'a mut W {
         self.variant(CH3OF_A::CLEAR)
     }
-    #[doc = "A capture event occured while CH0IF was already set"]
+    #[doc = "A capture event occured while CHnIF was already set"]
     #[inline(always)]
     pub fn over_capture(self) -> &'a mut W {
         self.variant(CH3OF_A::OVERCAPTURE)
@@ -116,9 +74,9 @@ impl<'a> CH3OF_W<'a> {
     }
 }
 #[doc = "Channel 2 Capture overflow flag"]
-pub type CH2OF_A = CH3OF_A;
+pub type CH2OF_A = crate::gd32f150::timer0::intf::CH0OF_A;
 #[doc = "Field `CH2OF` reader - Channel 2 Capture overflow flag"]
-pub type CH2OF_R = CH3OF_R;
+pub type CH2OF_R = crate::gd32f150::timer0::intf::CH0OF_R;
 #[doc = "Field `CH2OF` writer - Channel 2 Capture overflow flag"]
 pub struct CH2OF_W<'a> {
     w: &'a mut W,
@@ -134,7 +92,7 @@ impl<'a> CH2OF_W<'a> {
     pub fn clear(self) -> &'a mut W {
         self.variant(CH2OF_A::CLEAR)
     }
-    #[doc = "A capture event occured while CH0IF was already set"]
+    #[doc = "A capture event occured while CHnIF was already set"]
     #[inline(always)]
     pub fn over_capture(self) -> &'a mut W {
         self.variant(CH2OF_A::OVERCAPTURE)
@@ -157,9 +115,9 @@ impl<'a> CH2OF_W<'a> {
     }
 }
 #[doc = "Channel 1 Capture overflow flag"]
-pub type CH1OF_A = CH3OF_A;
+pub type CH1OF_A = crate::gd32f150::timer0::intf::CH0OF_A;
 #[doc = "Field `CH1OF` reader - Channel 1 Capture overflow flag"]
-pub type CH1OF_R = CH3OF_R;
+pub type CH1OF_R = crate::gd32f150::timer0::intf::CH0OF_R;
 #[doc = "Field `CH1OF` writer - Channel 1 Capture overflow flag"]
 pub struct CH1OF_W<'a> {
     w: &'a mut W,
@@ -175,7 +133,7 @@ impl<'a> CH1OF_W<'a> {
     pub fn clear(self) -> &'a mut W {
         self.variant(CH1OF_A::CLEAR)
     }
-    #[doc = "A capture event occured while CH0IF was already set"]
+    #[doc = "A capture event occured while CHnIF was already set"]
     #[inline(always)]
     pub fn over_capture(self) -> &'a mut W {
         self.variant(CH1OF_A::OVERCAPTURE)
@@ -198,9 +156,9 @@ impl<'a> CH1OF_W<'a> {
     }
 }
 #[doc = "Channel 0 Capture overflow flag"]
-pub type CH0OF_A = CH3OF_A;
+pub type CH0OF_A = crate::gd32f150::timer0::intf::CH0OF_A;
 #[doc = "Field `CH0OF` reader - Channel 0 Capture overflow flag"]
-pub type CH0OF_R = CH3OF_R;
+pub type CH0OF_R = crate::gd32f150::timer0::intf::CH0OF_R;
 #[doc = "Field `CH0OF` writer - Channel 0 Capture overflow flag"]
 pub struct CH0OF_W<'a> {
     w: &'a mut W,
@@ -216,7 +174,7 @@ impl<'a> CH0OF_W<'a> {
     pub fn clear(self) -> &'a mut W {
         self.variant(CH0OF_A::CLEAR)
     }
-    #[doc = "A capture event occured while CH0IF was already set"]
+    #[doc = "A capture event occured while CHnIF was already set"]
     #[inline(always)]
     pub fn over_capture(self) -> &'a mut W {
         self.variant(CH0OF_A::OVERCAPTURE)
@@ -321,52 +279,10 @@ impl<'a> TRGIF_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 Capture/Compare interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3IF_A {
-    #[doc = "0: No capture or compare interrupt occurred"]
-    CLEAR = 0,
-    #[doc = "1: A capture or compare event occurred"]
-    CAPTURECOMPARE = 1,
-}
-impl From<CH3IF_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3IF_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 Capture/Compare interrupt enable"]
+pub type CH3IF_A = crate::gd32f150::timer0::intf::CH0IF_A;
 #[doc = "Field `CH3IF` reader - Channel 3 Capture/Compare interrupt enable"]
-pub struct CH3IF_R(crate::FieldReader<bool, CH3IF_A>);
-impl CH3IF_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3IF_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3IF_A {
-        match self.bits {
-            false => CH3IF_A::CLEAR,
-            true => CH3IF_A::CAPTURECOMPARE,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CLEAR`"]
-    #[inline(always)]
-    pub fn is_clear(&self) -> bool {
-        **self == CH3IF_A::CLEAR
-    }
-    #[doc = "Checks if the value of the field is `CAPTURECOMPARE`"]
-    #[inline(always)]
-    pub fn is_capture_compare(&self) -> bool {
-        **self == CH3IF_A::CAPTURECOMPARE
-    }
-}
-impl core::ops::Deref for CH3IF_R {
-    type Target = crate::FieldReader<bool, CH3IF_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3IF_R = crate::gd32f150::timer0::intf::CH0IF_R;
 #[doc = "Field `CH3IF` writer - Channel 3 Capture/Compare interrupt enable"]
 pub struct CH3IF_W<'a> {
     w: &'a mut W,
@@ -405,9 +321,9 @@ impl<'a> CH3IF_W<'a> {
     }
 }
 #[doc = "Channel 2 Capture/Compare interrupt enable"]
-pub type CH2IF_A = CH3IF_A;
+pub type CH2IF_A = crate::gd32f150::timer0::intf::CH0IF_A;
 #[doc = "Field `CH2IF` reader - Channel 2 Capture/Compare interrupt enable"]
-pub type CH2IF_R = CH3IF_R;
+pub type CH2IF_R = crate::gd32f150::timer0::intf::CH0IF_R;
 #[doc = "Field `CH2IF` writer - Channel 2 Capture/Compare interrupt enable"]
 pub struct CH2IF_W<'a> {
     w: &'a mut W,
@@ -446,9 +362,9 @@ impl<'a> CH2IF_W<'a> {
     }
 }
 #[doc = "Channel 1 Capture/Compare interrupt enable"]
-pub type CH1IF_A = CH3IF_A;
+pub type CH1IF_A = crate::gd32f150::timer0::intf::CH0IF_A;
 #[doc = "Field `CH1IF` reader - Channel 1 Capture/Compare interrupt enable"]
-pub type CH1IF_R = CH3IF_R;
+pub type CH1IF_R = crate::gd32f150::timer0::intf::CH0IF_R;
 #[doc = "Field `CH1IF` writer - Channel 1 Capture/Compare interrupt enable"]
 pub struct CH1IF_W<'a> {
     w: &'a mut W,
@@ -487,9 +403,9 @@ impl<'a> CH1IF_W<'a> {
     }
 }
 #[doc = "Channel 0 Capture/Compare interrupt flag"]
-pub type CH0IF_A = CH3IF_A;
+pub type CH0IF_A = crate::gd32f150::timer0::intf::CH0IF_A;
 #[doc = "Field `CH0IF` reader - Channel 0 Capture/Compare interrupt flag"]
-pub type CH0IF_R = CH3IF_R;
+pub type CH0IF_R = crate::gd32f150::timer0::intf::CH0IF_R;
 #[doc = "Field `CH0IF` writer - Channel 0 Capture/Compare interrupt flag"]
 pub struct CH0IF_W<'a> {
     w: &'a mut W,
@@ -527,52 +443,10 @@ impl<'a> CH0IF_W<'a> {
         self.w
     }
 }
-#[doc = "Update interrupt flag\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum UPIF_A {
-    #[doc = "0: No update interrupt occurred"]
-    CLEAR = 0,
-    #[doc = "1: Update interrupt pending."]
-    UPDATEPENDING = 1,
-}
-impl From<UPIF_A> for bool {
-    #[inline(always)]
-    fn from(variant: UPIF_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Update interrupt flag"]
+pub type UPIF_A = crate::gd32f150::timer0::intf::UPIF_A;
 #[doc = "Field `UPIF` reader - Update interrupt flag"]
-pub struct UPIF_R(crate::FieldReader<bool, UPIF_A>);
-impl UPIF_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        UPIF_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> UPIF_A {
-        match self.bits {
-            false => UPIF_A::CLEAR,
-            true => UPIF_A::UPDATEPENDING,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CLEAR`"]
-    #[inline(always)]
-    pub fn is_clear(&self) -> bool {
-        **self == UPIF_A::CLEAR
-    }
-    #[doc = "Checks if the value of the field is `UPDATEPENDING`"]
-    #[inline(always)]
-    pub fn is_update_pending(&self) -> bool {
-        **self == UPIF_A::UPDATEPENDING
-    }
-}
-impl core::ops::Deref for UPIF_R {
-    type Target = crate::FieldReader<bool, UPIF_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type UPIF_R = crate::gd32f150::timer0::intf::UPIF_R;
 #[doc = "Field `UPIF` writer - Update interrupt flag"]
 pub struct UPIF_W<'a> {
     w: &'a mut W,
