@@ -322,52 +322,10 @@ impl<'a> UPDEN_W<'a> {
         self.w
     }
 }
-#[doc = "Break interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum BRKIE_A {
-    #[doc = "0: Break interrupt disabled"]
-    DISABLED = 0,
-    #[doc = "1: Break interrupt enabled"]
-    ENABLED = 1,
-}
-impl From<BRKIE_A> for bool {
-    #[inline(always)]
-    fn from(variant: BRKIE_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Break interrupt enable"]
+pub type BRKIE_A = crate::gd32f150::timer0::dmainten::BRKIE_A;
 #[doc = "Field `BRKIE` reader - Break interrupt enable"]
-pub struct BRKIE_R(crate::FieldReader<bool, BRKIE_A>);
-impl BRKIE_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        BRKIE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> BRKIE_A {
-        match self.bits {
-            false => BRKIE_A::DISABLED,
-            true => BRKIE_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == BRKIE_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == BRKIE_A::ENABLED
-    }
-}
-impl core::ops::Deref for BRKIE_R {
-    type Target = crate::FieldReader<bool, BRKIE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type BRKIE_R = crate::gd32f150::timer0::dmainten::BRKIE_R;
 #[doc = "Field `BRKIE` writer - Break interrupt enable"]
 pub struct BRKIE_W<'a> {
     w: &'a mut W,
@@ -488,52 +446,10 @@ impl<'a> TRGIE_W<'a> {
         self.w
     }
 }
-#[doc = "CMT interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CMTIE_A {
-    #[doc = "0: Commutation interrupt disabled"]
-    DISABLED = 0,
-    #[doc = "1: Commutation interrupt enabled"]
-    ENABLED = 1,
-}
-impl From<CMTIE_A> for bool {
-    #[inline(always)]
-    fn from(variant: CMTIE_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "CMT interrupt enable"]
+pub type CMTIE_A = crate::gd32f150::timer0::dmainten::CMTIE_A;
 #[doc = "Field `CMTIE` reader - CMT interrupt enable"]
-pub struct CMTIE_R(crate::FieldReader<bool, CMTIE_A>);
-impl CMTIE_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CMTIE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CMTIE_A {
-        match self.bits {
-            false => CMTIE_A::DISABLED,
-            true => CMTIE_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == CMTIE_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == CMTIE_A::ENABLED
-    }
-}
-impl core::ops::Deref for CMTIE_R {
-    type Target = crate::FieldReader<bool, CMTIE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CMTIE_R = crate::gd32f150::timer0::dmainten::CMTIE_R;
 #[doc = "Field `CMTIE` writer - CMT interrupt enable"]
 pub struct CMTIE_W<'a> {
     w: &'a mut W,
@@ -571,52 +487,10 @@ impl<'a> CMTIE_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 1 Capture/Compare interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH1IE_A {
-    #[doc = "0: Capture/compare interrupt disabled"]
-    DISABLED = 0,
-    #[doc = "1: Capture/compare interrupt enabled"]
-    ENABLED = 1,
-}
-impl From<CH1IE_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH1IE_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 1 Capture/Compare interrupt enable"]
+pub type CH1IE_A = crate::gd32f150::timer0::dmainten::CH0IE_A;
 #[doc = "Field `CH1IE` reader - Channel 1 Capture/Compare interrupt enable"]
-pub struct CH1IE_R(crate::FieldReader<bool, CH1IE_A>);
-impl CH1IE_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH1IE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH1IE_A {
-        match self.bits {
-            false => CH1IE_A::DISABLED,
-            true => CH1IE_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == CH1IE_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == CH1IE_A::ENABLED
-    }
-}
-impl core::ops::Deref for CH1IE_R {
-    type Target = crate::FieldReader<bool, CH1IE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH1IE_R = crate::gd32f150::timer0::dmainten::CH0IE_R;
 #[doc = "Field `CH1IE` writer - Channel 1 Capture/Compare interrupt enable"]
 pub struct CH1IE_W<'a> {
     w: &'a mut W,
@@ -655,9 +529,9 @@ impl<'a> CH1IE_W<'a> {
     }
 }
 #[doc = "Channel 0 Capture/Compare interrupt enable"]
-pub type CH0IE_A = CH1IE_A;
+pub type CH0IE_A = crate::gd32f150::timer0::dmainten::CH0IE_A;
 #[doc = "Field `CH0IE` reader - Channel 0 Capture/Compare interrupt enable"]
-pub type CH0IE_R = CH1IE_R;
+pub type CH0IE_R = crate::gd32f150::timer0::dmainten::CH0IE_R;
 #[doc = "Field `CH0IE` writer - Channel 0 Capture/Compare interrupt enable"]
 pub struct CH0IE_W<'a> {
     w: &'a mut W,
@@ -695,52 +569,10 @@ impl<'a> CH0IE_W<'a> {
         self.w
     }
 }
-#[doc = "Update interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum UPIE_A {
-    #[doc = "0: Update interrupt disabled"]
-    DISABLED = 0,
-    #[doc = "1: Update interrupt enabled"]
-    ENABLED = 1,
-}
-impl From<UPIE_A> for bool {
-    #[inline(always)]
-    fn from(variant: UPIE_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Update interrupt enable"]
+pub type UPIE_A = crate::gd32f150::timer0::dmainten::UPIE_A;
 #[doc = "Field `UPIE` reader - Update interrupt enable"]
-pub struct UPIE_R(crate::FieldReader<bool, UPIE_A>);
-impl UPIE_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        UPIE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> UPIE_A {
-        match self.bits {
-            false => UPIE_A::DISABLED,
-            true => UPIE_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == UPIE_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == UPIE_A::ENABLED
-    }
-}
-impl core::ops::Deref for UPIE_R {
-    type Target = crate::FieldReader<bool, UPIE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type UPIE_R = crate::gd32f150::timer0::dmainten::UPIE_R;
 #[doc = "Field `UPIE` writer - Update interrupt enable"]
 pub struct UPIE_W<'a> {
     w: &'a mut W,
