@@ -32,52 +32,10 @@ impl core::convert::From<crate::W<CHCTL1_OUTPUT_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Channel 3 output compare clear enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3COMCEN_A {
-    #[doc = "0: Output compare clear disabled"]
-    DISABLED = 0,
-    #[doc = "1: Output compare clear enabled"]
-    ENABLED = 1,
-}
-impl From<CH3COMCEN_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3COMCEN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 output compare clear enable"]
+pub type CH3COMCEN_A = crate::gd32f170::timer0::chctl0_output::CH0COMCEN_A;
 #[doc = "Field `CH3COMCEN` reader - Channel 3 output compare clear enable"]
-pub struct CH3COMCEN_R(crate::FieldReader<bool, CH3COMCEN_A>);
-impl CH3COMCEN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3COMCEN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3COMCEN_A {
-        match self.bits {
-            false => CH3COMCEN_A::DISABLED,
-            true => CH3COMCEN_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == CH3COMCEN_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == CH3COMCEN_A::ENABLED
-    }
-}
-impl core::ops::Deref for CH3COMCEN_R {
-    type Target = crate::FieldReader<bool, CH3COMCEN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3COMCEN_R = crate::gd32f170::timer0::chctl0_output::CH0COMCEN_R;
 #[doc = "Field `CH3COMCEN` writer - Channel 3 output compare clear enable"]
 pub struct CH3COMCEN_W<'a> {
     w: &'a mut W,
@@ -115,102 +73,10 @@ impl<'a> CH3COMCEN_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 compare output control\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CH3COMCTL_A {
-    #[doc = "0: The comparison between the output compare register CHyCV and the counter CNT has no effect on the outputs"]
-    FROZEN = 0,
-    #[doc = "1: Set channel to active level on match. OxCPRE signal is forced high when the counter matches the capture/compare register CHyCV"]
-    ACTIVEONMATCH = 1,
-    #[doc = "2: Set channel to inactive level on match. OxCPRE signal is forced low when the counter matches the capture/compare register CHyCV"]
-    INACTIVEONMATCH = 2,
-    #[doc = "3: OxCPRE toggles when CNT=CHyCV"]
-    TOGGLE = 3,
-    #[doc = "4: OxCPRE is forced low"]
-    FORCEINACTIVE = 4,
-    #[doc = "5: OxCPRE is forced high"]
-    FORCEACTIVE = 5,
-    #[doc = "6: In upcounting, channel is active as long as CNT<CHyCV else inactive. In downcounting, channel is inactive as long as CNT>CHyCV else active"]
-    PWMMODE0 = 6,
-    #[doc = "7: Inversely to PwmMode0"]
-    PWMMODE1 = 7,
-}
-impl From<CH3COMCTL_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CH3COMCTL_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Channel 3 compare output control"]
+pub type CH3COMCTL_A = crate::gd32f170::timer0::chctl0_output::CH0COMCTL_A;
 #[doc = "Field `CH3COMCTL` reader - Channel 3 compare output control"]
-pub struct CH3COMCTL_R(crate::FieldReader<u8, CH3COMCTL_A>);
-impl CH3COMCTL_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CH3COMCTL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3COMCTL_A {
-        match self.bits {
-            0 => CH3COMCTL_A::FROZEN,
-            1 => CH3COMCTL_A::ACTIVEONMATCH,
-            2 => CH3COMCTL_A::INACTIVEONMATCH,
-            3 => CH3COMCTL_A::TOGGLE,
-            4 => CH3COMCTL_A::FORCEINACTIVE,
-            5 => CH3COMCTL_A::FORCEACTIVE,
-            6 => CH3COMCTL_A::PWMMODE0,
-            7 => CH3COMCTL_A::PWMMODE1,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `FROZEN`"]
-    #[inline(always)]
-    pub fn is_frozen(&self) -> bool {
-        **self == CH3COMCTL_A::FROZEN
-    }
-    #[doc = "Checks if the value of the field is `ACTIVEONMATCH`"]
-    #[inline(always)]
-    pub fn is_active_on_match(&self) -> bool {
-        **self == CH3COMCTL_A::ACTIVEONMATCH
-    }
-    #[doc = "Checks if the value of the field is `INACTIVEONMATCH`"]
-    #[inline(always)]
-    pub fn is_inactive_on_match(&self) -> bool {
-        **self == CH3COMCTL_A::INACTIVEONMATCH
-    }
-    #[doc = "Checks if the value of the field is `TOGGLE`"]
-    #[inline(always)]
-    pub fn is_toggle(&self) -> bool {
-        **self == CH3COMCTL_A::TOGGLE
-    }
-    #[doc = "Checks if the value of the field is `FORCEINACTIVE`"]
-    #[inline(always)]
-    pub fn is_force_inactive(&self) -> bool {
-        **self == CH3COMCTL_A::FORCEINACTIVE
-    }
-    #[doc = "Checks if the value of the field is `FORCEACTIVE`"]
-    #[inline(always)]
-    pub fn is_force_active(&self) -> bool {
-        **self == CH3COMCTL_A::FORCEACTIVE
-    }
-    #[doc = "Checks if the value of the field is `PWMMODE0`"]
-    #[inline(always)]
-    pub fn is_pwm_mode0(&self) -> bool {
-        **self == CH3COMCTL_A::PWMMODE0
-    }
-    #[doc = "Checks if the value of the field is `PWMMODE1`"]
-    #[inline(always)]
-    pub fn is_pwm_mode1(&self) -> bool {
-        **self == CH3COMCTL_A::PWMMODE1
-    }
-}
-impl core::ops::Deref for CH3COMCTL_R {
-    type Target = crate::FieldReader<u8, CH3COMCTL_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3COMCTL_R = crate::gd32f170::timer0::chctl0_output::CH0COMCTL_R;
 #[doc = "Field `CH3COMCTL` writer - Channel 3 compare output control"]
 pub struct CH3COMCTL_W<'a> {
     w: &'a mut W,
@@ -268,52 +134,10 @@ impl<'a> CH3COMCTL_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 compare output control\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3COMSEN_A {
-    #[doc = "0: Preload register on CHyCV disabled. New values written to CHyCV are taken into account immediately"]
-    DISABLED = 0,
-    #[doc = "1: Preload register on CHyCV enabled. Preload value is loaded into active register on each update event"]
-    ENABLED = 1,
-}
-impl From<CH3COMSEN_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3COMSEN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 compare output control"]
+pub type CH3COMSEN_A = crate::gd32f170::timer0::chctl0_output::CH0COMSEN_A;
 #[doc = "Field `CH3COMSEN` reader - Channel 3 compare output control"]
-pub struct CH3COMSEN_R(crate::FieldReader<bool, CH3COMSEN_A>);
-impl CH3COMSEN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3COMSEN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3COMSEN_A {
-        match self.bits {
-            false => CH3COMSEN_A::DISABLED,
-            true => CH3COMSEN_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == CH3COMSEN_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == CH3COMSEN_A::ENABLED
-    }
-}
-impl core::ops::Deref for CH3COMSEN_R {
-    type Target = crate::FieldReader<bool, CH3COMSEN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3COMSEN_R = crate::gd32f170::timer0::chctl0_output::CH0COMSEN_R;
 #[doc = "Field `CH3COMSEN` writer - Channel 3 compare output control"]
 pub struct CH3COMSEN_W<'a> {
     w: &'a mut W,
@@ -351,52 +175,10 @@ impl<'a> CH3COMSEN_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 output compare fast enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3COMFEN_A {
-    #[doc = "0: The minimum delay from an edge is 5 clock cycles"]
-    SLOW = 0,
-    #[doc = "1: The minimum delay from an edge is 3 clock cycles"]
-    FAST = 1,
-}
-impl From<CH3COMFEN_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3COMFEN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 output compare fast enable"]
+pub type CH3COMFEN_A = crate::gd32f170::timer0::chctl0_output::CH0COMFEN_A;
 #[doc = "Field `CH3COMFEN` reader - Channel 3 output compare fast enable"]
-pub struct CH3COMFEN_R(crate::FieldReader<bool, CH3COMFEN_A>);
-impl CH3COMFEN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3COMFEN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3COMFEN_A {
-        match self.bits {
-            false => CH3COMFEN_A::SLOW,
-            true => CH3COMFEN_A::FAST,
-        }
-    }
-    #[doc = "Checks if the value of the field is `SLOW`"]
-    #[inline(always)]
-    pub fn is_slow(&self) -> bool {
-        **self == CH3COMFEN_A::SLOW
-    }
-    #[doc = "Checks if the value of the field is `FAST`"]
-    #[inline(always)]
-    pub fn is_fast(&self) -> bool {
-        **self == CH3COMFEN_A::FAST
-    }
-}
-impl core::ops::Deref for CH3COMFEN_R {
-    type Target = crate::FieldReader<bool, CH3COMFEN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3COMFEN_R = crate::gd32f170::timer0::chctl0_output::CH0COMFEN_R;
 #[doc = "Field `CH3COMFEN` writer - Channel 3 output compare fast enable"]
 pub struct CH3COMFEN_W<'a> {
     w: &'a mut W,
@@ -434,70 +216,10 @@ impl<'a> CH3COMFEN_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 mode selection\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum CH3MS_A {
-    #[doc = "0: Channel is configured as output"]
-    OUTPUT = 0,
-    #[doc = "1: Channel is configured as input, ISx is connected to CI0FE0"]
-    CI0 = 1,
-    #[doc = "2: Channel is configured as input, ISx is connected to CI1FE0"]
-    CI1 = 2,
-    #[doc = "3: Channel is configured as input, ISx is connected to ITS"]
-    ITS = 3,
-}
-impl From<CH3MS_A> for u8 {
-    #[inline(always)]
-    fn from(variant: CH3MS_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Channel 3 mode selection"]
+pub type CH3MS_A = crate::gd32f170::timer0::chctl0_output::CH0MS_A;
 #[doc = "Field `CH3MS` reader - Channel 3 mode selection"]
-pub struct CH3MS_R(crate::FieldReader<u8, CH3MS_A>);
-impl CH3MS_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        CH3MS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3MS_A {
-        match self.bits {
-            0 => CH3MS_A::OUTPUT,
-            1 => CH3MS_A::CI0,
-            2 => CH3MS_A::CI1,
-            3 => CH3MS_A::ITS,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `OUTPUT`"]
-    #[inline(always)]
-    pub fn is_output(&self) -> bool {
-        **self == CH3MS_A::OUTPUT
-    }
-    #[doc = "Checks if the value of the field is `CI0`"]
-    #[inline(always)]
-    pub fn is_ci0(&self) -> bool {
-        **self == CH3MS_A::CI0
-    }
-    #[doc = "Checks if the value of the field is `CI1`"]
-    #[inline(always)]
-    pub fn is_ci1(&self) -> bool {
-        **self == CH3MS_A::CI1
-    }
-    #[doc = "Checks if the value of the field is `ITS`"]
-    #[inline(always)]
-    pub fn is_its(&self) -> bool {
-        **self == CH3MS_A::ITS
-    }
-}
-impl core::ops::Deref for CH3MS_R {
-    type Target = crate::FieldReader<u8, CH3MS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3MS_R = crate::gd32f170::timer0::chctl0_output::CH0MS_R;
 #[doc = "Field `CH3MS` writer - Channel 3 mode selection"]
 pub struct CH3MS_W<'a> {
     w: &'a mut W,
@@ -536,9 +258,9 @@ impl<'a> CH3MS_W<'a> {
     }
 }
 #[doc = "Channel 2 output compare clear enable"]
-pub type CH2COMCEN_A = CH3COMCEN_A;
+pub type CH2COMCEN_A = crate::gd32f170::timer0::chctl0_output::CH0COMCEN_A;
 #[doc = "Field `CH2COMCEN` reader - Channel 2 output compare clear enable"]
-pub type CH2COMCEN_R = CH3COMCEN_R;
+pub type CH2COMCEN_R = crate::gd32f170::timer0::chctl0_output::CH0COMCEN_R;
 #[doc = "Field `CH2COMCEN` writer - Channel 2 output compare clear enable"]
 pub struct CH2COMCEN_W<'a> {
     w: &'a mut W,
@@ -577,9 +299,9 @@ impl<'a> CH2COMCEN_W<'a> {
     }
 }
 #[doc = "Channel 2 compare output control"]
-pub type CH2COMCTL_A = CH3COMCTL_A;
+pub type CH2COMCTL_A = crate::gd32f170::timer0::chctl0_output::CH0COMCTL_A;
 #[doc = "Field `CH2COMCTL` reader - Channel 2 compare output control"]
-pub type CH2COMCTL_R = CH3COMCTL_R;
+pub type CH2COMCTL_R = crate::gd32f170::timer0::chctl0_output::CH0COMCTL_R;
 #[doc = "Field `CH2COMCTL` writer - Channel 2 compare output control"]
 pub struct CH2COMCTL_W<'a> {
     w: &'a mut W,
@@ -638,9 +360,9 @@ impl<'a> CH2COMCTL_W<'a> {
     }
 }
 #[doc = "Channel 2 output compare shadow enable"]
-pub type CH2COMSEN_A = CH3COMSEN_A;
+pub type CH2COMSEN_A = crate::gd32f170::timer0::chctl0_output::CH0COMSEN_A;
 #[doc = "Field `CH2COMSEN` reader - Channel 2 output compare shadow enable"]
-pub type CH2COMSEN_R = CH3COMSEN_R;
+pub type CH2COMSEN_R = crate::gd32f170::timer0::chctl0_output::CH0COMSEN_R;
 #[doc = "Field `CH2COMSEN` writer - Channel 2 output compare shadow enable"]
 pub struct CH2COMSEN_W<'a> {
     w: &'a mut W,
@@ -679,9 +401,9 @@ impl<'a> CH2COMSEN_W<'a> {
     }
 }
 #[doc = "Channel 2 output compare fast enable"]
-pub type CH2COMFEN_A = CH3COMFEN_A;
+pub type CH2COMFEN_A = crate::gd32f170::timer0::chctl0_output::CH0COMFEN_A;
 #[doc = "Field `CH2COMFEN` reader - Channel 2 output compare fast enable"]
-pub type CH2COMFEN_R = CH3COMFEN_R;
+pub type CH2COMFEN_R = crate::gd32f170::timer0::chctl0_output::CH0COMFEN_R;
 #[doc = "Field `CH2COMFEN` writer - Channel 2 output compare fast enable"]
 pub struct CH2COMFEN_W<'a> {
     w: &'a mut W,
@@ -720,9 +442,9 @@ impl<'a> CH2COMFEN_W<'a> {
     }
 }
 #[doc = "Channel 2 mode selection"]
-pub type CH2MS_A = CH3MS_A;
+pub type CH2MS_A = crate::gd32f170::timer0::chctl0_output::CH0MS_A;
 #[doc = "Field `CH2MS` reader - Channel 2 mode selection"]
-pub type CH2MS_R = CH3MS_R;
+pub type CH2MS_R = crate::gd32f170::timer0::chctl0_output::CH0MS_R;
 #[doc = "Field `CH2MS` writer - Channel 2 mode selection"]
 pub struct CH2MS_W<'a> {
     w: &'a mut W,
