@@ -32,52 +32,10 @@ impl core::convert::From<crate::W<INTF_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Channel 1 Capture overflow flag\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH1OF_A {
-    #[doc = "0: No over capture occurred"]
-    CLEAR = 0,
-    #[doc = "1: A capture event occured while CH0IF was already set"]
-    OVERCAPTURE = 1,
-}
-impl From<CH1OF_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH1OF_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 1 Capture overflow flag"]
+pub type CH1OF_A = crate::gd32f170::timer0::intf::CH0OF_A;
 #[doc = "Field `CH1OF` reader - Channel 1 Capture overflow flag"]
-pub struct CH1OF_R(crate::FieldReader<bool, CH1OF_A>);
-impl CH1OF_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH1OF_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH1OF_A {
-        match self.bits {
-            false => CH1OF_A::CLEAR,
-            true => CH1OF_A::OVERCAPTURE,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CLEAR`"]
-    #[inline(always)]
-    pub fn is_clear(&self) -> bool {
-        **self == CH1OF_A::CLEAR
-    }
-    #[doc = "Checks if the value of the field is `OVERCAPTURE`"]
-    #[inline(always)]
-    pub fn is_over_capture(&self) -> bool {
-        **self == CH1OF_A::OVERCAPTURE
-    }
-}
-impl core::ops::Deref for CH1OF_R {
-    type Target = crate::FieldReader<bool, CH1OF_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH1OF_R = crate::gd32f170::timer0::intf::CH0OF_R;
 #[doc = "Field `CH1OF` writer - Channel 1 Capture overflow flag"]
 pub struct CH1OF_W<'a> {
     w: &'a mut W,
@@ -93,7 +51,7 @@ impl<'a> CH1OF_W<'a> {
     pub fn clear(self) -> &'a mut W {
         self.variant(CH1OF_A::CLEAR)
     }
-    #[doc = "A capture event occured while CH0IF was already set"]
+    #[doc = "A capture event occured while CHnIF was already set"]
     #[inline(always)]
     pub fn over_capture(self) -> &'a mut W {
         self.variant(CH1OF_A::OVERCAPTURE)
@@ -116,9 +74,9 @@ impl<'a> CH1OF_W<'a> {
     }
 }
 #[doc = "Channel 0 Capture overflow flag"]
-pub type CH0OF_A = CH1OF_A;
+pub type CH0OF_A = crate::gd32f170::timer0::intf::CH0OF_A;
 #[doc = "Field `CH0OF` reader - Channel 0 Capture overflow flag"]
-pub type CH0OF_R = CH1OF_R;
+pub type CH0OF_R = crate::gd32f170::timer0::intf::CH0OF_R;
 #[doc = "Field `CH0OF` writer - Channel 0 Capture overflow flag"]
 pub struct CH0OF_W<'a> {
     w: &'a mut W,
@@ -134,7 +92,7 @@ impl<'a> CH0OF_W<'a> {
     pub fn clear(self) -> &'a mut W {
         self.variant(CH0OF_A::CLEAR)
     }
-    #[doc = "A capture event occured while CH0IF was already set"]
+    #[doc = "A capture event occured while CHnIF was already set"]
     #[inline(always)]
     pub fn over_capture(self) -> &'a mut W {
         self.variant(CH0OF_A::OVERCAPTURE)
@@ -156,52 +114,10 @@ impl<'a> CH0OF_W<'a> {
         self.w
     }
 }
-#[doc = "Break interrupt flag\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum BRKIF_A {
-    #[doc = "0: No active level break detected"]
-    CLEAR = 0,
-    #[doc = "1: Active level detected"]
-    BREAK = 1,
-}
-impl From<BRKIF_A> for bool {
-    #[inline(always)]
-    fn from(variant: BRKIF_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Break interrupt flag"]
+pub type BRKIF_A = crate::gd32f170::timer0::intf::BRKIF_A;
 #[doc = "Field `BRKIF` reader - Break interrupt flag"]
-pub struct BRKIF_R(crate::FieldReader<bool, BRKIF_A>);
-impl BRKIF_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        BRKIF_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> BRKIF_A {
-        match self.bits {
-            false => BRKIF_A::CLEAR,
-            true => BRKIF_A::BREAK,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CLEAR`"]
-    #[inline(always)]
-    pub fn is_clear(&self) -> bool {
-        **self == BRKIF_A::CLEAR
-    }
-    #[doc = "Checks if the value of the field is `BREAK`"]
-    #[inline(always)]
-    pub fn is_break(&self) -> bool {
-        **self == BRKIF_A::BREAK
-    }
-}
-impl core::ops::Deref for BRKIF_R {
-    type Target = crate::FieldReader<bool, BRKIF_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type BRKIF_R = crate::gd32f170::timer0::intf::BRKIF_R;
 #[doc = "Field `BRKIF` writer - Break interrupt flag"]
 pub struct BRKIF_W<'a> {
     w: &'a mut W,
@@ -322,52 +238,10 @@ impl<'a> TRGIF_W<'a> {
         self.w
     }
 }
-#[doc = "Channel commutation interrupt flag\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CMTIF_A {
-    #[doc = "0: No channel commutation event occured"]
-    CLEAR = 0,
-    #[doc = "1: Channel commutation event occurred"]
-    COMMUTATION = 1,
-}
-impl From<CMTIF_A> for bool {
-    #[inline(always)]
-    fn from(variant: CMTIF_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel commutation interrupt flag"]
+pub type CMTIF_A = crate::gd32f170::timer0::intf::CMTIF_A;
 #[doc = "Field `CMTIF` reader - Channel commutation interrupt flag"]
-pub struct CMTIF_R(crate::FieldReader<bool, CMTIF_A>);
-impl CMTIF_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CMTIF_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CMTIF_A {
-        match self.bits {
-            false => CMTIF_A::CLEAR,
-            true => CMTIF_A::COMMUTATION,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CLEAR`"]
-    #[inline(always)]
-    pub fn is_clear(&self) -> bool {
-        **self == CMTIF_A::CLEAR
-    }
-    #[doc = "Checks if the value of the field is `COMMUTATION`"]
-    #[inline(always)]
-    pub fn is_commutation(&self) -> bool {
-        **self == CMTIF_A::COMMUTATION
-    }
-}
-impl core::ops::Deref for CMTIF_R {
-    type Target = crate::FieldReader<bool, CMTIF_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CMTIF_R = crate::gd32f170::timer0::intf::CMTIF_R;
 #[doc = "Field `CMTIF` writer - Channel commutation interrupt flag"]
 pub struct CMTIF_W<'a> {
     w: &'a mut W,
@@ -405,52 +279,10 @@ impl<'a> CMTIF_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 1 interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH1IF_A {
-    #[doc = "0: No capture or compare interrupt occurred"]
-    CLEAR = 0,
-    #[doc = "1: A capture or compare event occurred"]
-    CAPTURECOMPARE = 1,
-}
-impl From<CH1IF_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH1IF_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 1 interrupt enable"]
+pub type CH1IF_A = crate::gd32f170::timer0::intf::CH0IF_A;
 #[doc = "Field `CH1IF` reader - Channel 1 interrupt enable"]
-pub struct CH1IF_R(crate::FieldReader<bool, CH1IF_A>);
-impl CH1IF_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH1IF_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH1IF_A {
-        match self.bits {
-            false => CH1IF_A::CLEAR,
-            true => CH1IF_A::CAPTURECOMPARE,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CLEAR`"]
-    #[inline(always)]
-    pub fn is_clear(&self) -> bool {
-        **self == CH1IF_A::CLEAR
-    }
-    #[doc = "Checks if the value of the field is `CAPTURECOMPARE`"]
-    #[inline(always)]
-    pub fn is_capture_compare(&self) -> bool {
-        **self == CH1IF_A::CAPTURECOMPARE
-    }
-}
-impl core::ops::Deref for CH1IF_R {
-    type Target = crate::FieldReader<bool, CH1IF_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH1IF_R = crate::gd32f170::timer0::intf::CH0IF_R;
 #[doc = "Field `CH1IF` writer - Channel 1 interrupt enable"]
 pub struct CH1IF_W<'a> {
     w: &'a mut W,
@@ -489,9 +321,9 @@ impl<'a> CH1IF_W<'a> {
     }
 }
 #[doc = "Channel 0 interrupt enable"]
-pub type CH0IF_A = CH1IF_A;
+pub type CH0IF_A = crate::gd32f170::timer0::intf::CH0IF_A;
 #[doc = "Field `CH0IF` reader - Channel 0 interrupt enable"]
-pub type CH0IF_R = CH1IF_R;
+pub type CH0IF_R = crate::gd32f170::timer0::intf::CH0IF_R;
 #[doc = "Field `CH0IF` writer - Channel 0 interrupt enable"]
 pub struct CH0IF_W<'a> {
     w: &'a mut W,
@@ -529,52 +361,10 @@ impl<'a> CH0IF_W<'a> {
         self.w
     }
 }
-#[doc = "Update interrupt flag\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum UPIF_A {
-    #[doc = "0: No update interrupt occurred"]
-    CLEAR = 0,
-    #[doc = "1: Update interrupt pending."]
-    UPDATEPENDING = 1,
-}
-impl From<UPIF_A> for bool {
-    #[inline(always)]
-    fn from(variant: UPIF_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Update interrupt flag"]
+pub type UPIF_A = crate::gd32f170::timer0::intf::UPIF_A;
 #[doc = "Field `UPIF` reader - Update interrupt flag"]
-pub struct UPIF_R(crate::FieldReader<bool, UPIF_A>);
-impl UPIF_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        UPIF_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> UPIF_A {
-        match self.bits {
-            false => UPIF_A::CLEAR,
-            true => UPIF_A::UPDATEPENDING,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CLEAR`"]
-    #[inline(always)]
-    pub fn is_clear(&self) -> bool {
-        **self == UPIF_A::CLEAR
-    }
-    #[doc = "Checks if the value of the field is `UPDATEPENDING`"]
-    #[inline(always)]
-    pub fn is_update_pending(&self) -> bool {
-        **self == UPIF_A::UPDATEPENDING
-    }
-}
-impl core::ops::Deref for UPIF_R {
-    type Target = crate::FieldReader<bool, UPIF_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type UPIF_R = crate::gd32f170::timer0::intf::UPIF_R;
 #[doc = "Field `UPIF` writer - Update interrupt flag"]
 pub struct UPIF_W<'a> {
     w: &'a mut W,
