@@ -487,52 +487,10 @@ impl<'a> TRGIE_W<'a> {
         self.w
     }
 }
-#[doc = "Channel 3 Capture/Compare interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CH3IE_A {
-    #[doc = "0: Capture/compare interrupt disabled"]
-    DISABLED = 0,
-    #[doc = "1: Capture/compare interrupt enabled"]
-    ENABLED = 1,
-}
-impl From<CH3IE_A> for bool {
-    #[inline(always)]
-    fn from(variant: CH3IE_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Channel 3 Capture/Compare interrupt enable"]
+pub type CH3IE_A = crate::gd32f190::timer0::dmainten::CH0IE_A;
 #[doc = "Field `CH3IE` reader - Channel 3 Capture/Compare interrupt enable"]
-pub struct CH3IE_R(crate::FieldReader<bool, CH3IE_A>);
-impl CH3IE_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CH3IE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CH3IE_A {
-        match self.bits {
-            false => CH3IE_A::DISABLED,
-            true => CH3IE_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == CH3IE_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == CH3IE_A::ENABLED
-    }
-}
-impl core::ops::Deref for CH3IE_R {
-    type Target = crate::FieldReader<bool, CH3IE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CH3IE_R = crate::gd32f190::timer0::dmainten::CH0IE_R;
 #[doc = "Field `CH3IE` writer - Channel 3 Capture/Compare interrupt enable"]
 pub struct CH3IE_W<'a> {
     w: &'a mut W,
@@ -571,9 +529,9 @@ impl<'a> CH3IE_W<'a> {
     }
 }
 #[doc = "Channel 2 Capture/Compare interrupt enable"]
-pub type CH2IE_A = CH3IE_A;
+pub type CH2IE_A = crate::gd32f190::timer0::dmainten::CH0IE_A;
 #[doc = "Field `CH2IE` reader - Channel 2 Capture/Compare interrupt enable"]
-pub type CH2IE_R = CH3IE_R;
+pub type CH2IE_R = crate::gd32f190::timer0::dmainten::CH0IE_R;
 #[doc = "Field `CH2IE` writer - Channel 2 Capture/Compare interrupt enable"]
 pub struct CH2IE_W<'a> {
     w: &'a mut W,
@@ -612,9 +570,9 @@ impl<'a> CH2IE_W<'a> {
     }
 }
 #[doc = "Channel 1 Capture/Compare interrupt enable"]
-pub type CH1IE_A = CH3IE_A;
+pub type CH1IE_A = crate::gd32f190::timer0::dmainten::CH0IE_A;
 #[doc = "Field `CH1IE` reader - Channel 1 Capture/Compare interrupt enable"]
-pub type CH1IE_R = CH3IE_R;
+pub type CH1IE_R = crate::gd32f190::timer0::dmainten::CH0IE_R;
 #[doc = "Field `CH1IE` writer - Channel 1 Capture/Compare interrupt enable"]
 pub struct CH1IE_W<'a> {
     w: &'a mut W,
@@ -653,9 +611,9 @@ impl<'a> CH1IE_W<'a> {
     }
 }
 #[doc = "Channel 0 Capture/Compare interrupt enable"]
-pub type CH0IE_A = CH3IE_A;
+pub type CH0IE_A = crate::gd32f190::timer0::dmainten::CH0IE_A;
 #[doc = "Field `CH0IE` reader - Channel 0 Capture/Compare interrupt enable"]
-pub type CH0IE_R = CH3IE_R;
+pub type CH0IE_R = crate::gd32f190::timer0::dmainten::CH0IE_R;
 #[doc = "Field `CH0IE` writer - Channel 0 Capture/Compare interrupt enable"]
 pub struct CH0IE_W<'a> {
     w: &'a mut W,
@@ -693,52 +651,10 @@ impl<'a> CH0IE_W<'a> {
         self.w
     }
 }
-#[doc = "Update Capture/Compare interrupt enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum UPIE_A {
-    #[doc = "0: Update interrupt disabled"]
-    DISABLED = 0,
-    #[doc = "1: Update interrupt enabled"]
-    ENABLED = 1,
-}
-impl From<UPIE_A> for bool {
-    #[inline(always)]
-    fn from(variant: UPIE_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Update Capture/Compare interrupt enable"]
+pub type UPIE_A = crate::gd32f190::timer0::dmainten::UPIE_A;
 #[doc = "Field `UPIE` reader - Update Capture/Compare interrupt enable"]
-pub struct UPIE_R(crate::FieldReader<bool, UPIE_A>);
-impl UPIE_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        UPIE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> UPIE_A {
-        match self.bits {
-            false => UPIE_A::DISABLED,
-            true => UPIE_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == UPIE_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == UPIE_A::ENABLED
-    }
-}
-impl core::ops::Deref for UPIE_R {
-    type Target = crate::FieldReader<bool, UPIE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type UPIE_R = crate::gd32f190::timer0::dmainten::UPIE_R;
 #[doc = "Field `UPIE` writer - Update Capture/Compare interrupt enable"]
 pub struct UPIE_W<'a> {
     w: &'a mut W,
