@@ -32,52 +32,10 @@ impl core::convert::From<crate::W<CCHP_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Primary output enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum POEN_A {
-    #[doc = "0: Channel outputs are disabled"]
-    DISABLED = 0,
-    #[doc = "1: Channel outputs are enabled"]
-    ENABLED = 1,
-}
-impl From<POEN_A> for bool {
-    #[inline(always)]
-    fn from(variant: POEN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Primary output enable"]
+pub type POEN_A = crate::gd32f190::timer0::cchp::POEN_A;
 #[doc = "Field `POEN` reader - Primary output enable"]
-pub struct POEN_R(crate::FieldReader<bool, POEN_A>);
-impl POEN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        POEN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> POEN_A {
-        match self.bits {
-            false => POEN_A::DISABLED,
-            true => POEN_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == POEN_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == POEN_A::ENABLED
-    }
-}
-impl core::ops::Deref for POEN_R {
-    type Target = crate::FieldReader<bool, POEN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type POEN_R = crate::gd32f190::timer0::cchp::POEN_R;
 #[doc = "Field `POEN` writer - Primary output enable"]
 pub struct POEN_W<'a> {
     w: &'a mut W,
@@ -115,52 +73,10 @@ impl<'a> POEN_W<'a> {
         self.w
     }
 }
-#[doc = "Output automatic enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum OAEN_A {
-    #[doc = "0: POEN cannot be set by hardware"]
-    MANUAL = 0,
-    #[doc = "1: POEN can be set by hardware automatically at the next update event"]
-    AUTOMATIC = 1,
-}
-impl From<OAEN_A> for bool {
-    #[inline(always)]
-    fn from(variant: OAEN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Output automatic enable"]
+pub type OAEN_A = crate::gd32f190::timer0::cchp::OAEN_A;
 #[doc = "Field `OAEN` reader - Output automatic enable"]
-pub struct OAEN_R(crate::FieldReader<bool, OAEN_A>);
-impl OAEN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        OAEN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> OAEN_A {
-        match self.bits {
-            false => OAEN_A::MANUAL,
-            true => OAEN_A::AUTOMATIC,
-        }
-    }
-    #[doc = "Checks if the value of the field is `MANUAL`"]
-    #[inline(always)]
-    pub fn is_manual(&self) -> bool {
-        **self == OAEN_A::MANUAL
-    }
-    #[doc = "Checks if the value of the field is `AUTOMATIC`"]
-    #[inline(always)]
-    pub fn is_automatic(&self) -> bool {
-        **self == OAEN_A::AUTOMATIC
-    }
-}
-impl core::ops::Deref for OAEN_R {
-    type Target = crate::FieldReader<bool, OAEN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type OAEN_R = crate::gd32f190::timer0::cchp::OAEN_R;
 #[doc = "Field `OAEN` writer - Output automatic enable"]
 pub struct OAEN_W<'a> {
     w: &'a mut W,
@@ -198,52 +114,10 @@ impl<'a> OAEN_W<'a> {
         self.w
     }
 }
-#[doc = "Break polarity\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum BRKP_A {
-    #[doc = "0: BRKIN is active low"]
-    INVERTED = 0,
-    #[doc = "1: BRKIN is active high"]
-    NOTINVERTED = 1,
-}
-impl From<BRKP_A> for bool {
-    #[inline(always)]
-    fn from(variant: BRKP_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Break polarity"]
+pub type BRKP_A = crate::gd32f190::timer0::cchp::BRKP_A;
 #[doc = "Field `BRKP` reader - Break polarity"]
-pub struct BRKP_R(crate::FieldReader<bool, BRKP_A>);
-impl BRKP_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        BRKP_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> BRKP_A {
-        match self.bits {
-            false => BRKP_A::INVERTED,
-            true => BRKP_A::NOTINVERTED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `INVERTED`"]
-    #[inline(always)]
-    pub fn is_inverted(&self) -> bool {
-        **self == BRKP_A::INVERTED
-    }
-    #[doc = "Checks if the value of the field is `NOTINVERTED`"]
-    #[inline(always)]
-    pub fn is_not_inverted(&self) -> bool {
-        **self == BRKP_A::NOTINVERTED
-    }
-}
-impl core::ops::Deref for BRKP_R {
-    type Target = crate::FieldReader<bool, BRKP_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type BRKP_R = crate::gd32f190::timer0::cchp::BRKP_R;
 #[doc = "Field `BRKP` writer - Break polarity"]
 pub struct BRKP_W<'a> {
     w: &'a mut W,
@@ -281,52 +155,10 @@ impl<'a> BRKP_W<'a> {
         self.w
     }
 }
-#[doc = "Break enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum BRKEN_A {
-    #[doc = "0: Break inputs disabled"]
-    DISABLED = 0,
-    #[doc = "1: Break inputs enabled"]
-    ENABLED = 1,
-}
-impl From<BRKEN_A> for bool {
-    #[inline(always)]
-    fn from(variant: BRKEN_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Break enable"]
+pub type BRKEN_A = crate::gd32f190::timer0::cchp::BRKEN_A;
 #[doc = "Field `BRKEN` reader - Break enable"]
-pub struct BRKEN_R(crate::FieldReader<bool, BRKEN_A>);
-impl BRKEN_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        BRKEN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> BRKEN_A {
-        match self.bits {
-            false => BRKEN_A::DISABLED,
-            true => BRKEN_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == BRKEN_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == BRKEN_A::ENABLED
-    }
-}
-impl core::ops::Deref for BRKEN_R {
-    type Target = crate::FieldReader<bool, BRKEN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type BRKEN_R = crate::gd32f190::timer0::cchp::BRKEN_R;
 #[doc = "Field `BRKEN` writer - Break enable"]
 pub struct BRKEN_W<'a> {
     w: &'a mut W,
@@ -364,52 +196,10 @@ impl<'a> BRKEN_W<'a> {
         self.w
     }
 }
-#[doc = "Run mode off-state configure\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ROS_A {
-    #[doc = "0: When POEN is set, the channel output signals are disabled"]
-    DISABLED = 0,
-    #[doc = "1: When POEN is set, the channel output signals are enabled"]
-    ENABLED = 1,
-}
-impl From<ROS_A> for bool {
-    #[inline(always)]
-    fn from(variant: ROS_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Run mode off-state configure"]
+pub type ROS_A = crate::gd32f190::timer0::cchp::ROS_A;
 #[doc = "Field `ROS` reader - Run mode off-state configure"]
-pub struct ROS_R(crate::FieldReader<bool, ROS_A>);
-impl ROS_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ROS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ROS_A {
-        match self.bits {
-            false => ROS_A::DISABLED,
-            true => ROS_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == ROS_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == ROS_A::ENABLED
-    }
-}
-impl core::ops::Deref for ROS_R {
-    type Target = crate::FieldReader<bool, ROS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ROS_R = crate::gd32f190::timer0::cchp::ROS_R;
 #[doc = "Field `ROS` writer - Run mode off-state configure"]
 pub struct ROS_W<'a> {
     w: &'a mut W,
@@ -447,52 +237,10 @@ impl<'a> ROS_W<'a> {
         self.w
     }
 }
-#[doc = "Idle mode off-state configure\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum IOS_A {
-    #[doc = "0: When POEN is reset, the channel output signals are disabled"]
-    DISABLED = 0,
-    #[doc = "1: When POEN is reset, the channel output signals are enabled"]
-    ENABLED = 1,
-}
-impl From<IOS_A> for bool {
-    #[inline(always)]
-    fn from(variant: IOS_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Idle mode off-state configure"]
+pub type IOS_A = crate::gd32f190::timer0::cchp::IOS_A;
 #[doc = "Field `IOS` reader - Idle mode off-state configure"]
-pub struct IOS_R(crate::FieldReader<bool, IOS_A>);
-impl IOS_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        IOS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> IOS_A {
-        match self.bits {
-            false => IOS_A::DISABLED,
-            true => IOS_A::ENABLED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == IOS_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `ENABLED`"]
-    #[inline(always)]
-    pub fn is_enabled(&self) -> bool {
-        **self == IOS_A::ENABLED
-    }
-}
-impl core::ops::Deref for IOS_R {
-    type Target = crate::FieldReader<bool, IOS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type IOS_R = crate::gd32f190::timer0::cchp::IOS_R;
 #[doc = "Field `IOS` writer - Idle mode off-state configure"]
 pub struct IOS_W<'a> {
     w: &'a mut W,
@@ -530,70 +278,10 @@ impl<'a> IOS_W<'a> {
         self.w
     }
 }
-#[doc = "Complementary register protect control\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-#[repr(u8)]
-pub enum PROT_A {
-    #[doc = "0: Write protection disabled"]
-    DISABLED = 0,
-    #[doc = "1: Protection mode 0"]
-    MODE0 = 1,
-    #[doc = "2: Protection mode 1"]
-    MODE1 = 2,
-    #[doc = "3: Protection mode 2"]
-    MODE2 = 3,
-}
-impl From<PROT_A> for u8 {
-    #[inline(always)]
-    fn from(variant: PROT_A) -> Self {
-        variant as _
-    }
-}
+#[doc = "Complementary register protect control"]
+pub type PROT_A = crate::gd32f190::timer0::cchp::PROT_A;
 #[doc = "Field `PROT` reader - Complementary register protect control"]
-pub struct PROT_R(crate::FieldReader<u8, PROT_A>);
-impl PROT_R {
-    pub(crate) fn new(bits: u8) -> Self {
-        PROT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> PROT_A {
-        match self.bits {
-            0 => PROT_A::DISABLED,
-            1 => PROT_A::MODE0,
-            2 => PROT_A::MODE1,
-            3 => PROT_A::MODE2,
-            _ => unreachable!(),
-        }
-    }
-    #[doc = "Checks if the value of the field is `DISABLED`"]
-    #[inline(always)]
-    pub fn is_disabled(&self) -> bool {
-        **self == PROT_A::DISABLED
-    }
-    #[doc = "Checks if the value of the field is `MODE0`"]
-    #[inline(always)]
-    pub fn is_mode0(&self) -> bool {
-        **self == PROT_A::MODE0
-    }
-    #[doc = "Checks if the value of the field is `MODE1`"]
-    #[inline(always)]
-    pub fn is_mode1(&self) -> bool {
-        **self == PROT_A::MODE1
-    }
-    #[doc = "Checks if the value of the field is `MODE2`"]
-    #[inline(always)]
-    pub fn is_mode2(&self) -> bool {
-        **self == PROT_A::MODE2
-    }
-}
-impl core::ops::Deref for PROT_R {
-    type Target = crate::FieldReader<u8, PROT_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type PROT_R = crate::gd32f190::timer0::cchp::PROT_R;
 #[doc = "Field `PROT` writer - Complementary register protect control"]
 pub struct PROT_W<'a> {
     w: &'a mut W,
