@@ -32,52 +32,10 @@ impl core::convert::From<crate::W<CTL1_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "Idle state of channel 1 output\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ISO1_A {
-    #[doc = "0: CH1_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    LOW = 0,
-    #[doc = "1: CH1_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    HIGH = 1,
-}
-impl From<ISO1_A> for bool {
-    #[inline(always)]
-    fn from(variant: ISO1_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Idle state of channel 1 output"]
+pub type ISO1_A = crate::gd32f190::timer0::ctl1::ISO0_A;
 #[doc = "Field `ISO1` reader - Idle state of channel 1 output"]
-pub struct ISO1_R(crate::FieldReader<bool, ISO1_A>);
-impl ISO1_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ISO1_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ISO1_A {
-        match self.bits {
-            false => ISO1_A::LOW,
-            true => ISO1_A::HIGH,
-        }
-    }
-    #[doc = "Checks if the value of the field is `LOW`"]
-    #[inline(always)]
-    pub fn is_low(&self) -> bool {
-        **self == ISO1_A::LOW
-    }
-    #[doc = "Checks if the value of the field is `HIGH`"]
-    #[inline(always)]
-    pub fn is_high(&self) -> bool {
-        **self == ISO1_A::HIGH
-    }
-}
-impl core::ops::Deref for ISO1_R {
-    type Target = crate::FieldReader<bool, ISO1_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ISO1_R = crate::gd32f190::timer0::ctl1::ISO0_R;
 #[doc = "Field `ISO1` writer - Idle state of channel 1 output"]
 pub struct ISO1_W<'a> {
     w: &'a mut W,
@@ -88,12 +46,12 @@ impl<'a> ISO1_W<'a> {
     pub fn variant(self, variant: ISO1_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH1_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=0 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO1_A::LOW)
     }
-    #[doc = "CH1_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=1 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO1_A::HIGH)
@@ -115,52 +73,10 @@ impl<'a> ISO1_W<'a> {
         self.w
     }
 }
-#[doc = "Idle state of channel 1 output\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ISO0N_A {
-    #[doc = "0: CH0_ON=0 when POEN=0"]
-    LOW = 0,
-    #[doc = "1: CH0_ON=1 when POEN=0"]
-    HIGH = 1,
-}
-impl From<ISO0N_A> for bool {
-    #[inline(always)]
-    fn from(variant: ISO0N_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Idle state of channel 1 output"]
+pub type ISO0N_A = crate::gd32f190::timer0::ctl1::ISO0N_A;
 #[doc = "Field `ISO0N` reader - Idle state of channel 1 output"]
-pub struct ISO0N_R(crate::FieldReader<bool, ISO0N_A>);
-impl ISO0N_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ISO0N_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ISO0N_A {
-        match self.bits {
-            false => ISO0N_A::LOW,
-            true => ISO0N_A::HIGH,
-        }
-    }
-    #[doc = "Checks if the value of the field is `LOW`"]
-    #[inline(always)]
-    pub fn is_low(&self) -> bool {
-        **self == ISO0N_A::LOW
-    }
-    #[doc = "Checks if the value of the field is `HIGH`"]
-    #[inline(always)]
-    pub fn is_high(&self) -> bool {
-        **self == ISO0N_A::HIGH
-    }
-}
-impl core::ops::Deref for ISO0N_R {
-    type Target = crate::FieldReader<bool, ISO0N_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ISO0N_R = crate::gd32f190::timer0::ctl1::ISO0N_R;
 #[doc = "Field `ISO0N` writer - Idle state of channel 1 output"]
 pub struct ISO0N_W<'a> {
     w: &'a mut W,
@@ -171,12 +87,12 @@ impl<'a> ISO0N_W<'a> {
     pub fn variant(self, variant: ISO0N_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH0_ON=0 when POEN=0"]
+    #[doc = "CHn_ON=0 when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO0N_A::LOW)
     }
-    #[doc = "CH0_ON=1 when POEN=0"]
+    #[doc = "CHn_ON=1 when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO0N_A::HIGH)
@@ -198,52 +114,10 @@ impl<'a> ISO0N_W<'a> {
         self.w
     }
 }
-#[doc = "Idle state of channel 0 output\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ISO0_A {
-    #[doc = "0: CH0_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    LOW = 0,
-    #[doc = "1: CH0_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
-    HIGH = 1,
-}
-impl From<ISO0_A> for bool {
-    #[inline(always)]
-    fn from(variant: ISO0_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Idle state of channel 0 output"]
+pub type ISO0_A = crate::gd32f190::timer0::ctl1::ISO0_A;
 #[doc = "Field `ISO0` reader - Idle state of channel 0 output"]
-pub struct ISO0_R(crate::FieldReader<bool, ISO0_A>);
-impl ISO0_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ISO0_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ISO0_A {
-        match self.bits {
-            false => ISO0_A::LOW,
-            true => ISO0_A::HIGH,
-        }
-    }
-    #[doc = "Checks if the value of the field is `LOW`"]
-    #[inline(always)]
-    pub fn is_low(&self) -> bool {
-        **self == ISO0_A::LOW
-    }
-    #[doc = "Checks if the value of the field is `HIGH`"]
-    #[inline(always)]
-    pub fn is_high(&self) -> bool {
-        **self == ISO0_A::HIGH
-    }
-}
-impl core::ops::Deref for ISO0_R {
-    type Target = crate::FieldReader<bool, ISO0_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ISO0_R = crate::gd32f190::timer0::ctl1::ISO0_R;
 #[doc = "Field `ISO0` writer - Idle state of channel 0 output"]
 pub struct ISO0_W<'a> {
     w: &'a mut W,
@@ -254,12 +128,12 @@ impl<'a> ISO0_W<'a> {
     pub fn variant(self, variant: ISO0_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "CH0_O=0 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=0 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
         self.variant(ISO0_A::LOW)
     }
-    #[doc = "CH0_O=1 (after a dead-time if CH0_ON is implemented) when POEN=0"]
+    #[doc = "CHn_O=1 (after a dead-time if CHn_ON is implemented) when POEN=0"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
         self.variant(ISO0_A::HIGH)
@@ -452,52 +326,10 @@ impl<'a> DMAS_W<'a> {
         self.w
     }
 }
-#[doc = "Commutation control shadow register update control\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CCUC_A {
-    #[doc = "0: Capture/compare are updated only by setting the CMTG bit"]
-    DEFAULT = 0,
-    #[doc = "1: Capture/compare are updated by setting the CMTG bit or when an rising edge occurs on TRGI"]
-    WITHRISINGEDGE = 1,
-}
-impl From<CCUC_A> for bool {
-    #[inline(always)]
-    fn from(variant: CCUC_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Commutation control shadow register update control"]
+pub type CCUC_A = crate::gd32f190::timer0::ctl1::CCUC_A;
 #[doc = "Field `CCUC` reader - Commutation control shadow register update control"]
-pub struct CCUC_R(crate::FieldReader<bool, CCUC_A>);
-impl CCUC_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CCUC_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CCUC_A {
-        match self.bits {
-            false => CCUC_A::DEFAULT,
-            true => CCUC_A::WITHRISINGEDGE,
-        }
-    }
-    #[doc = "Checks if the value of the field is `DEFAULT`"]
-    #[inline(always)]
-    pub fn is_default(&self) -> bool {
-        **self == CCUC_A::DEFAULT
-    }
-    #[doc = "Checks if the value of the field is `WITHRISINGEDGE`"]
-    #[inline(always)]
-    pub fn is_with_rising_edge(&self) -> bool {
-        **self == CCUC_A::WITHRISINGEDGE
-    }
-}
-impl core::ops::Deref for CCUC_R {
-    type Target = crate::FieldReader<bool, CCUC_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CCUC_R = crate::gd32f190::timer0::ctl1::CCUC_R;
 #[doc = "Field `CCUC` writer - Commutation control shadow register update control"]
 pub struct CCUC_W<'a> {
     w: &'a mut W,
@@ -535,52 +367,10 @@ impl<'a> CCUC_W<'a> {
         self.w
     }
 }
-#[doc = "Commutation control shadow register enable\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum CCSE_A {
-    #[doc = "0: The shadow registers for CHxEN, CHxNEN and CHxCOMCTL bits are disabled"]
-    NOTPRELOADED = 0,
-    #[doc = "1: The shadow registers for CHxEN, CHxNEN and CHxCOMCTL bits are enabled"]
-    PRELOADED = 1,
-}
-impl From<CCSE_A> for bool {
-    #[inline(always)]
-    fn from(variant: CCSE_A) -> Self {
-        variant as u8 != 0
-    }
-}
+#[doc = "Commutation control shadow register enable"]
+pub type CCSE_A = crate::gd32f190::timer0::ctl1::CCSE_A;
 #[doc = "Field `CCSE` reader - Commutation control shadow register enable"]
-pub struct CCSE_R(crate::FieldReader<bool, CCSE_A>);
-impl CCSE_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        CCSE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> CCSE_A {
-        match self.bits {
-            false => CCSE_A::NOTPRELOADED,
-            true => CCSE_A::PRELOADED,
-        }
-    }
-    #[doc = "Checks if the value of the field is `NOTPRELOADED`"]
-    #[inline(always)]
-    pub fn is_not_preloaded(&self) -> bool {
-        **self == CCSE_A::NOTPRELOADED
-    }
-    #[doc = "Checks if the value of the field is `PRELOADED`"]
-    #[inline(always)]
-    pub fn is_preloaded(&self) -> bool {
-        **self == CCSE_A::PRELOADED
-    }
-}
-impl core::ops::Deref for CCSE_R {
-    type Target = crate::FieldReader<bool, CCSE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CCSE_R = crate::gd32f190::timer0::ctl1::CCSE_R;
 #[doc = "Field `CCSE` writer - Commutation control shadow register enable"]
 pub struct CCSE_W<'a> {
     w: &'a mut W,
